#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .nb_gradient import nb_gradient as nb_gradient_cls
from .nb_gradient_dbns import nb_gradient_dbns as nb_gradient_dbns_cls
class nb_gradient_boundary_option(Group):
    """
    Set ggnb options.
    """

    fluent_name = "nb-gradient-boundary-option"

    child_names = \
        ['nb_gradient', 'nb_gradient_dbns']

    nb_gradient: nb_gradient_cls = nb_gradient_cls
    """
    nb_gradient child of nb_gradient_boundary_option.
    """
    nb_gradient_dbns: nb_gradient_dbns_cls = nb_gradient_dbns_cls
    """
    nb_gradient_dbns child of nb_gradient_boundary_option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .design_points_1 import design_points as design_points_cls
from .current_design_point import current_design_point as current_design_point_cls
class parametric_studies_child(Group):
    """
    'child_object_type' of parametric_studies.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'design_points', 'current_design_point']

    name: name_cls = name_cls
    """
    name child of parametric_studies_child.
    """
    design_points: design_points_cls = design_points_cls
    """
    design_points child of parametric_studies_child.
    """
    current_design_point: current_design_point_cls = current_design_point_cls
    """
    current_design_point child of parametric_studies_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .type_2 import type as type_cls
from .minimum_1 import minimum as minimum_cls
from .maximum_1 import maximum as maximum_cls
class range_options(Group):
    """
    'range_options' child.
    """

    fluent_name = "range-options"

    child_names = \
        ['type', 'minimum', 'maximum']

    type: type_cls = type_cls
    """
    type child of range_options.
    """
    minimum: minimum_cls = minimum_cls
    """
    minimum child of range_options.
    """
    maximum: maximum_cls = maximum_cls
    """
    maximum child of range_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class include_viscous_fsi_force(Boolean):
    """
    Enable inclusion of viscous fsi force.
    """

    fluent_name = "include-viscous-fsi-force?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .species_mass_flow import species_mass_flow as species_mass_flow_cls
from .element_mass_flow import element_mass_flow as element_mass_flow_cls
from .uds_flow import uds_flow as uds_flow_cls
class flow(Group):
    """
    'flow' child.
    """

    fluent_name = "flow"

    command_names = \
        ['species_mass_flow', 'element_mass_flow', 'uds_flow']

    species_mass_flow: species_mass_flow_cls = species_mass_flow_cls
    """
    species_mass_flow command of flow.
    """
    element_mass_flow: element_mass_flow_cls = element_mass_flow_cls
    """
    element_mass_flow command of flow.
    """
    uds_flow: uds_flow_cls = uds_flow_cls
    """
    uds_flow command of flow.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class color_by_type(Boolean):
    """
    Determine whether to color meshes by type or by surface (ID).
    """

    fluent_name = "color-by-type?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .numbers import numbers as numbers_cls
from .rules import rules as rules_cls
from .log_scale_2 import log_scale as log_scale_cls
from .auto_scale_1 import auto_scale as auto_scale_cls
from .labels import labels as labels_cls
class axes(Group):
    """
    'axes' child.
    """

    fluent_name = "axes"

    child_names = \
        ['numbers', 'rules', 'log_scale', 'auto_scale', 'labels']

    numbers: numbers_cls = numbers_cls
    """
    numbers child of axes.
    """
    rules: rules_cls = rules_cls
    """
    rules child of axes.
    """
    log_scale: log_scale_cls = log_scale_cls
    """
    log_scale child of axes.
    """
    auto_scale: auto_scale_cls = auto_scale_cls
    """
    auto_scale child of axes.
    """
    labels: labels_cls = labels_cls
    """
    labels child of axes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .display_frame import display_frame as display_frame_cls
from .hide_frame import hide_frame as hide_frame_cls
from .reference_frames_child import reference_frames_child

class reference_frames(NamedObject[reference_frames_child], _CreatableNamedObjectMixin[reference_frames_child]):
    """
    'reference_frames' child.
    """

    fluent_name = "reference-frames"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy', 'display_frame',
         'hide_frame']

    delete: delete_cls = delete_cls
    """
    delete command of reference_frames.
    """
    list: list_cls = list_cls
    """
    list command of reference_frames.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of reference_frames.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of reference_frames.
    """
    display_frame: display_frame_cls = display_frame_cls
    """
    display_frame command of reference_frames.
    """
    hide_frame: hide_frame_cls = hide_frame_cls
    """
    hide_frame command of reference_frames.
    """
    child_object_type: reference_frames_child = reference_frames_child
    """
    child_object_type of reference_frames.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class file:
    fluent_name = ...
    child_names = ...
    single_precision_coordinates = ...
    binary_legacy_files = ...
    cff_files = ...
    convert_hanging_nodes_during_read = ...
    async_optimize = ...
    write_pdat = ...
    auto_save = ...
    export = ...
    import_ = ...
    parametric_project = ...
    cffio_options = ...
    batch_options = ...
    command_names = ...

    def define_macro(self, file_name: str):
        """
        Save input to a named macro.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def execute_macro(self, macro_filename: str):
        """
        Run a previously defined macro.
        
        Parameters
        ----------
            macro_filename : str
                'macro_filename' child.
        
        """

    def read_macros(self, file_name: str):
        """
        Read macro definitions from a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read(self, file_type: str, file_name: str, pdf_file_name: str, lightweight_setup: bool):
        """
        'read' command.
        
        Parameters
        ----------
            file_type : str
                'file_type' child.
            file_name : str
                'file_name' child.
            pdf_file_name : str
                'pdf_file_name' child.
            lightweight_setup : bool
                'lightweight_setup' child.
        
        """

    def read_case(self, file_name: str, pdf_file_name: str):
        """
        'read_case' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            pdf_file_name : str
                'pdf_file_name' child.
        
        """

    def read_case_data(self, file_name: str, pdf_file_name: str):
        """
        'read_case_data' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            pdf_file_name : str
                'pdf_file_name' child.
        
        """

    def read_case_setting(self, file_name: str, pdf_file_name: str):
        """
        'read_case_setting' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            pdf_file_name : str
                'pdf_file_name' child.
        
        """

    def read_data(self, file_name: str):
        """
        'read_data' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_mesh(self, file_name: str):
        """
        'read_mesh' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_surface_mesh(self, filename: str, unit: str):
        """
        Read surface meshes.
        
        Parameters
        ----------
            filename : str
                Path to surface mesh file.
            unit : str
                Unit in which the mesh was created.
        
        """

    def read_journal(self, file_name_list: List[str]):
        """
        Read a journal file.
        
        Parameters
        ----------
            file_name_list : typing.List[str]
                'file_name_list' child.
        
        """

    def start_journal(self, file_name: str):
        """
        Start recording all input in a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def stop_journal(self, ):
        """
        Stop recording input and close the journal file.
        """

    def replace_mesh(self, file_name: str):
        """
        'replace_mesh' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def write(self, file_type: str, file_name: str):
        """
        'write' command.
        
        Parameters
        ----------
            file_type : str
                'file_type' child.
            file_name : str
                'file_name' child.
        
        """

    def write_case(self, file_name: str):
        """
        'write_case' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def write_data(self, file_name: str):
        """
        'write_data' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def write_case_data(self, file_name: str):
        """
        'write_case_data' command.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_settings(self, file_name: str):
        """
        Read and set boundary conditions from specified file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_field_functions(self, file_name: str):
        """
        Read custom field-function definitions from a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_injections(self, file_name: str):
        """
        Read all DPM injections from a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_profile(self, file_name: str):
        """
        Read boundary profile data (*.prof, *.csv). Default is *.prof.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_pdf(self, file_name: str):
        """
        Read a PDF file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def read_isat_table(self, file_name: str):
        """
        Read an ISAT table.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def show_configuration(self, ):
        """
        Display current release and version information.
        """

    def stop_macro(self, ):
        """
        Stop recording input to a macro.
        """

    def start_transcript(self, file_name: str):
        """
        Start recording input and output in a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def stop_transcript(self, ):
        """
        Stop recording input and output and close the transcript file.
        """

    def data_file_options(self, reset_defined_derived_quantities: bool, derived_quantities: List[str]):
        """
        Set derived quantities to be written in data file.
        
        Parameters
        ----------
            reset_defined_derived_quantities : bool
                'reset_defined_derived_quantities' child.
            derived_quantities : typing.List[str]
                'derived_quantities' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .uds_bc_child import uds_bc_child

class discretization_scheme(NamedObject[uds_bc_child], _CreatableNamedObjectMixin[uds_bc_child]):
    """
    'discretization_scheme' child.
    """

    fluent_name = "discretization-scheme"

    child_object_type: uds_bc_child = uds_bc_child
    """
    child_object_type of discretization_scheme.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_2 import enable as enable_cls
from .components import components as components_cls
from .gravity_mrf_behavior import gravity_mrf_behavior as gravity_mrf_behavior_cls
class gravity(Group):
    """
    'gravity' child.
    """

    fluent_name = "gravity"

    child_names = \
        ['enable', 'components', 'gravity_mrf_behavior']

    enable: enable_cls = enable_cls
    """
    enable child of gravity.
    """
    components: components_cls = components_cls
    """
    components child of gravity.
    """
    gravity_mrf_behavior: gravity_mrf_behavior_cls = gravity_mrf_behavior_cls
    """
    gravity_mrf_behavior child of gravity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class reaction_diffusion_balance(Boolean):
    """
    Enable/disable reaction diffusion balance at reacting surface for surface reactions.
    """

    fluent_name = "reaction-diffusion-balance"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .discrete_phase_bc_type import discrete_phase_bc_type as discrete_phase_bc_type_cls
from .dem_collision_partner import dem_collision_partner as dem_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_norm_coeff import dpm_bc_norm_coeff as dpm_bc_norm_coeff_cls
from .dpm_bc_tang_coeff import dpm_bc_tang_coeff as dpm_bc_tang_coeff_cls
from .dpm_bc_frictn_coeff import dpm_bc_frictn_coeff as dpm_bc_frictn_coeff_cls
from .discrete_phase_bc_function import discrete_phase_bc_function as discrete_phase_bc_function_cls
from .dpm_film_splash_nsamp import dpm_film_splash_nsamp as dpm_film_splash_nsamp_cls
from .dpm_crit_temp_option import dpm_crit_temp_option as dpm_crit_temp_option_cls
from .dpm_critical_temp_factor import dpm_critical_temp_factor as dpm_critical_temp_factor_cls
from .dpm_calibratable_temp import dpm_calibratable_temp as dpm_calibratable_temp_cls
from .dpm_impingement_splashing_model import dpm_impingement_splashing_model as dpm_impingement_splashing_model_cls
from .dpm_upper_deposition_limit_offset import dpm_upper_deposition_limit_offset as dpm_upper_deposition_limit_offset_cls
from .dpm_deposition_delta_t import dpm_deposition_delta_t as dpm_deposition_delta_t_cls
from .dpm_laplace_number_constant import dpm_laplace_number_constant as dpm_laplace_number_constant_cls
from .dpm_partial_evaporation_ratio import dpm_partial_evaporation_ratio as dpm_partial_evaporation_ratio_cls
from .ra_roughness import ra_roughness as ra_roughness_cls
from .rz_roughness import rz_roughness as rz_roughness_cls
from .rq_roughness import rq_roughness as rq_roughness_cls
from .rsm_roughness import rsm_roughness as rsm_roughness_cls
from .enable_generic_erosion_model import enable_generic_erosion_model as enable_generic_erosion_model_cls
from .generic_impact_angle_function import generic_impact_angle_function as generic_impact_angle_function_cls
from .generic_diameter_function import generic_diameter_function as generic_diameter_function_cls
from .generic_velocity_exponent_function import generic_velocity_exponent_function as generic_velocity_exponent_function_cls
from .enable_finnie_erosion_model import enable_finnie_erosion_model as enable_finnie_erosion_model_cls
from .dpm_bc_erosion_finnie_k import dpm_bc_erosion_finnie_k as dpm_bc_erosion_finnie_k_cls
from .dpm_bc_erosion_finnie_vel_exp import dpm_bc_erosion_finnie_vel_exp as dpm_bc_erosion_finnie_vel_exp_cls
from .dpm_bc_erosion_finnie_max_erosion_angle import dpm_bc_erosion_finnie_max_erosion_angle as dpm_bc_erosion_finnie_max_erosion_angle_cls
from .dpm_bc_erosion_mclaury import dpm_bc_erosion_mclaury as dpm_bc_erosion_mclaury_cls
from .dpm_bc_erosion_mclaury_a import dpm_bc_erosion_mclaury_a as dpm_bc_erosion_mclaury_a_cls
from .dpm_bc_erosion_mclaury_vel_exp import dpm_bc_erosion_mclaury_vel_exp as dpm_bc_erosion_mclaury_vel_exp_cls
from .dpm_bc_erosion_mclaury_transition_angle import dpm_bc_erosion_mclaury_transition_angle as dpm_bc_erosion_mclaury_transition_angle_cls
from .dpm_bc_erosion_mclaury_b import dpm_bc_erosion_mclaury_b as dpm_bc_erosion_mclaury_b_cls
from .dpm_bc_erosion_mclaury_c import dpm_bc_erosion_mclaury_c as dpm_bc_erosion_mclaury_c_cls
from .dpm_bc_erosion_mclaury_w import dpm_bc_erosion_mclaury_w as dpm_bc_erosion_mclaury_w_cls
from .dpm_bc_erosion_mclaury_x import dpm_bc_erosion_mclaury_x as dpm_bc_erosion_mclaury_x_cls
from .dpm_bc_erosion_mclaury_y import dpm_bc_erosion_mclaury_y as dpm_bc_erosion_mclaury_y_cls
from .dpm_bc_erosion_oka import dpm_bc_erosion_oka as dpm_bc_erosion_oka_cls
from .dpm_bc_erosion_oka_e90 import dpm_bc_erosion_oka_e90 as dpm_bc_erosion_oka_e90_cls
from .dpm_bc_erosion_oka_hv import dpm_bc_erosion_oka_hv as dpm_bc_erosion_oka_hv_cls
from .dpm_bc_erosion_oka_n1 import dpm_bc_erosion_oka_n1 as dpm_bc_erosion_oka_n1_cls
from .dpm_bc_erosion_oka_n2 import dpm_bc_erosion_oka_n2 as dpm_bc_erosion_oka_n2_cls
from .dpm_bc_erosion_oka_k2 import dpm_bc_erosion_oka_k2 as dpm_bc_erosion_oka_k2_cls
from .dpm_bc_erosion_oka_k3 import dpm_bc_erosion_oka_k3 as dpm_bc_erosion_oka_k3_cls
from .dpm_bc_erosion_oka_dref import dpm_bc_erosion_oka_dref as dpm_bc_erosion_oka_dref_cls
from .dpm_bc_erosion_oka_vref import dpm_bc_erosion_oka_vref as dpm_bc_erosion_oka_vref_cls
from .dpm_bc_erosion_dnv import dpm_bc_erosion_dnv as dpm_bc_erosion_dnv_cls
from .dpm_bc_erosion_dnv_k import dpm_bc_erosion_dnv_k as dpm_bc_erosion_dnv_k_cls
from .dpm_bc_erosion_dnv_n import dpm_bc_erosion_dnv_n as dpm_bc_erosion_dnv_n_cls
from .dpm_bc_erosion_dnv_ductile import dpm_bc_erosion_dnv_ductile as dpm_bc_erosion_dnv_ductile_cls
from .dpm_bc_erosion_shear import dpm_bc_erosion_shear as dpm_bc_erosion_shear_cls
from .dpm_bc_erosion_shear_v import dpm_bc_erosion_shear_v as dpm_bc_erosion_shear_v_cls
from .dpm_bc_erosion_shear_c import dpm_bc_erosion_shear_c as dpm_bc_erosion_shear_c_cls
from .dpm_bc_erosion_shear_packing_limit import dpm_bc_erosion_shear_packing_limit as dpm_bc_erosion_shear_packing_limit_cls
from .dpm_bc_erosion_shielding import dpm_bc_erosion_shielding as dpm_bc_erosion_shielding_cls
from .dpm_wall_heat_exchange import dpm_wall_heat_exchange as dpm_wall_heat_exchange_cls
from .dpm_film_condensation import dpm_film_condensation as dpm_film_condensation_cls
from .dpm_film_bl_model import dpm_film_bl_model as dpm_film_bl_model_cls
from .dpm_particle_stripping import dpm_particle_stripping as dpm_particle_stripping_cls
from .dpm_critical_shear_stress import dpm_critical_shear_stress as dpm_critical_shear_stress_cls
from .dpm_film_separation_model import dpm_film_separation_model as dpm_film_separation_model_cls
from .dpm_critical_we_number import dpm_critical_we_number as dpm_critical_we_number_cls
from .dpm_film_separation_angle import dpm_film_separation_angle as dpm_film_separation_angle_cls
from .dpm_allow_lwf_to_vof import dpm_allow_lwf_to_vof as dpm_allow_lwf_to_vof_cls
from .dpm_allow_vof_to_lwf import dpm_allow_vof_to_lwf as dpm_allow_vof_to_lwf_cls
from .dpm_initialize_lwf import dpm_initialize_lwf as dpm_initialize_lwf_cls
from .dpm_initial_height import dpm_initial_height as dpm_initial_height_cls
from .film_velocity import film_velocity as film_velocity_cls
from .dpm_initial_temperature import dpm_initial_temperature as dpm_initial_temperature_cls
from .dpm_initial_injection import dpm_initial_injection as dpm_initial_injection_cls
from .film_parcel_surface_area_density import film_parcel_surface_area_density as film_parcel_surface_area_density_cls
from .minimum_number_of_parcels_per_face import minimum_number_of_parcels_per_face as minimum_number_of_parcels_per_face_cls
from .in_situ_data_reduction import in_situ_data_reduction as in_situ_data_reduction_cls
from .data_reduction import data_reduction as data_reduction_cls
from .set_as_eulerian_film_wall import set_as_eulerian_film_wall as set_as_eulerian_film_wall_cls
from .film_condition_type import film_condition_type as film_condition_type_cls
from .film_height import film_height as film_height_cls
from .flux_momentum import flux_momentum as flux_momentum_cls
from .relative_initial_film_velocity import relative_initial_film_velocity as relative_initial_film_velocity_cls
from .include_film_momentum_pressure import include_film_momentum_pressure as include_film_momentum_pressure_cls
from .film_temperature import film_temperature as film_temperature_cls
from .film_passive_scalar import film_passive_scalar as film_passive_scalar_cls
from .enable_film_source_terms import enable_film_source_terms as enable_film_source_terms_cls
from .film_mass_source import film_mass_source as film_mass_source_cls
from .momentum_source import momentum_source as momentum_source_cls
from .film_heat_source import film_heat_source as film_heat_source_cls
from .film_passive_scalar_source import film_passive_scalar_source as film_passive_scalar_source_cls
from .enable_film_phase_change import enable_film_phase_change as enable_film_phase_change_cls
from .phase_change_model import phase_change_model as phase_change_model_cls
from .film_condensation_constant import film_condensation_constant as film_condensation_constant_cls
from .film_vaporization_constant import film_vaporization_constant as film_vaporization_constant_cls
from .film_condensation_rate import film_condensation_rate as film_condensation_rate_cls
from .film_vaporization_rate import film_vaporization_rate as film_vaporization_rate_cls
from .enable_flow_momentum_coupling import enable_flow_momentum_coupling as enable_flow_momentum_coupling_cls
from .enable_dpm_wall_splash import enable_dpm_wall_splash as enable_dpm_wall_splash_cls
from .allow_film_boundary_separation import allow_film_boundary_separation as allow_film_boundary_separation_cls
from .impingement_model_1 import impingement_model as impingement_model_cls
from .number_of_splashed_particles import number_of_splashed_particles as number_of_splashed_particles_cls
from .critical_temperature_factor import critical_temperature_factor as critical_temperature_factor_cls
from .wall_roughness_length_ra import wall_roughness_length_ra as wall_roughness_length_ra_cls
from .wall_roughness_length_rz import wall_roughness_length_rz as wall_roughness_length_rz_cls
from .upper_deposition_limit_offset import upper_deposition_limit_offset as upper_deposition_limit_offset_cls
from .deposition_delta_t import deposition_delta_t as deposition_delta_t_cls
from .laplace_number_constant import laplace_number_constant as laplace_number_constant_cls
from .partial_evaporation_ratio import partial_evaporation_ratio as partial_evaporation_ratio_cls
from .enable_film_contact_angle_force import enable_film_contact_angle_force as enable_film_contact_angle_force_cls
from .film_contact_angle_mean import film_contact_angle_mean as film_contact_angle_mean_cls
from .film_contact_angle_rstd import film_contact_angle_rstd as film_contact_angle_rstd_cls
from .film_contact_angle_beta import film_contact_angle_beta as film_contact_angle_beta_cls
from .film_vof_coupling_high import film_vof_coupling_high as film_vof_coupling_high_cls
from .film_vof_trans_high import film_vof_trans_high as film_vof_trans_high_cls
from .film_vof_trans_high_relax import film_vof_trans_high_relax as film_vof_trans_high_relax_cls
from .film_vof_coupling_low import film_vof_coupling_low as film_vof_coupling_low_cls
from .film_vof_trans_low import film_vof_trans_low as film_vof_trans_low_cls
from .film_vof_trans_low_relax import film_vof_trans_low_relax as film_vof_trans_low_relax_cls
from .dpm_do_initialize_lwf_now import dpm_do_initialize_lwf_now as dpm_do_initialize_lwf_now_cls
class dpm(Group):
    """
    Help not available.
    """

    fluent_name = "dpm"

    child_names = \
        ['discrete_phase_bc_type', 'dem_collision_partner', 'reinj_inj',
         'dpm_bc_norm_coeff', 'dpm_bc_tang_coeff', 'dpm_bc_frictn_coeff',
         'discrete_phase_bc_function', 'dpm_film_splash_nsamp',
         'dpm_crit_temp_option', 'dpm_critical_temp_factor',
         'dpm_calibratable_temp', 'dpm_impingement_splashing_model',
         'dpm_upper_deposition_limit_offset', 'dpm_deposition_delta_t',
         'dpm_laplace_number_constant', 'dpm_partial_evaporation_ratio',
         'ra_roughness', 'rz_roughness', 'rq_roughness', 'rsm_roughness',
         'enable_generic_erosion_model', 'generic_impact_angle_function',
         'generic_diameter_function', 'generic_velocity_exponent_function',
         'enable_finnie_erosion_model', 'dpm_bc_erosion_finnie_k',
         'dpm_bc_erosion_finnie_vel_exp',
         'dpm_bc_erosion_finnie_max_erosion_angle', 'dpm_bc_erosion_mclaury',
         'dpm_bc_erosion_mclaury_a', 'dpm_bc_erosion_mclaury_vel_exp',
         'dpm_bc_erosion_mclaury_transition_angle',
         'dpm_bc_erosion_mclaury_b', 'dpm_bc_erosion_mclaury_c',
         'dpm_bc_erosion_mclaury_w', 'dpm_bc_erosion_mclaury_x',
         'dpm_bc_erosion_mclaury_y', 'dpm_bc_erosion_oka',
         'dpm_bc_erosion_oka_e90', 'dpm_bc_erosion_oka_hv',
         'dpm_bc_erosion_oka_n1', 'dpm_bc_erosion_oka_n2',
         'dpm_bc_erosion_oka_k2', 'dpm_bc_erosion_oka_k3',
         'dpm_bc_erosion_oka_dref', 'dpm_bc_erosion_oka_vref',
         'dpm_bc_erosion_dnv', 'dpm_bc_erosion_dnv_k', 'dpm_bc_erosion_dnv_n',
         'dpm_bc_erosion_dnv_ductile', 'dpm_bc_erosion_shear',
         'dpm_bc_erosion_shear_v', 'dpm_bc_erosion_shear_c',
         'dpm_bc_erosion_shear_packing_limit', 'dpm_bc_erosion_shielding',
         'dpm_wall_heat_exchange', 'dpm_film_condensation',
         'dpm_film_bl_model', 'dpm_particle_stripping',
         'dpm_critical_shear_stress', 'dpm_film_separation_model',
         'dpm_critical_we_number', 'dpm_film_separation_angle',
         'dpm_allow_lwf_to_vof', 'dpm_allow_vof_to_lwf', 'dpm_initialize_lwf',
         'dpm_initial_height', 'film_velocity', 'dpm_initial_temperature',
         'dpm_initial_injection', 'film_parcel_surface_area_density',
         'minimum_number_of_parcels_per_face', 'in_situ_data_reduction',
         'data_reduction', 'set_as_eulerian_film_wall', 'film_condition_type',
         'film_height', 'flux_momentum', 'relative_initial_film_velocity',
         'include_film_momentum_pressure', 'film_temperature',
         'film_passive_scalar', 'enable_film_source_terms',
         'film_mass_source', 'momentum_source', 'film_heat_source',
         'film_passive_scalar_source', 'enable_film_phase_change',
         'phase_change_model', 'film_condensation_constant',
         'film_vaporization_constant', 'film_condensation_rate',
         'film_vaporization_rate', 'enable_flow_momentum_coupling',
         'enable_dpm_wall_splash', 'allow_film_boundary_separation',
         'impingement_model', 'number_of_splashed_particles',
         'critical_temperature_factor', 'wall_roughness_length_ra',
         'wall_roughness_length_rz', 'upper_deposition_limit_offset',
         'deposition_delta_t', 'laplace_number_constant',
         'partial_evaporation_ratio', 'enable_film_contact_angle_force',
         'film_contact_angle_mean', 'film_contact_angle_rstd',
         'film_contact_angle_beta', 'film_vof_coupling_high',
         'film_vof_trans_high', 'film_vof_trans_high_relax',
         'film_vof_coupling_low', 'film_vof_trans_low',
         'film_vof_trans_low_relax']

    discrete_phase_bc_type: discrete_phase_bc_type_cls = discrete_phase_bc_type_cls
    """
    discrete_phase_bc_type child of dpm.
    """
    dem_collision_partner: dem_collision_partner_cls = dem_collision_partner_cls
    """
    dem_collision_partner child of dpm.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of dpm.
    """
    dpm_bc_norm_coeff: dpm_bc_norm_coeff_cls = dpm_bc_norm_coeff_cls
    """
    dpm_bc_norm_coeff child of dpm.
    """
    dpm_bc_tang_coeff: dpm_bc_tang_coeff_cls = dpm_bc_tang_coeff_cls
    """
    dpm_bc_tang_coeff child of dpm.
    """
    dpm_bc_frictn_coeff: dpm_bc_frictn_coeff_cls = dpm_bc_frictn_coeff_cls
    """
    dpm_bc_frictn_coeff child of dpm.
    """
    discrete_phase_bc_function: discrete_phase_bc_function_cls = discrete_phase_bc_function_cls
    """
    discrete_phase_bc_function child of dpm.
    """
    dpm_film_splash_nsamp: dpm_film_splash_nsamp_cls = dpm_film_splash_nsamp_cls
    """
    dpm_film_splash_nsamp child of dpm.
    """
    dpm_crit_temp_option: dpm_crit_temp_option_cls = dpm_crit_temp_option_cls
    """
    dpm_crit_temp_option child of dpm.
    """
    dpm_critical_temp_factor: dpm_critical_temp_factor_cls = dpm_critical_temp_factor_cls
    """
    dpm_critical_temp_factor child of dpm.
    """
    dpm_calibratable_temp: dpm_calibratable_temp_cls = dpm_calibratable_temp_cls
    """
    dpm_calibratable_temp child of dpm.
    """
    dpm_impingement_splashing_model: dpm_impingement_splashing_model_cls = dpm_impingement_splashing_model_cls
    """
    dpm_impingement_splashing_model child of dpm.
    """
    dpm_upper_deposition_limit_offset: dpm_upper_deposition_limit_offset_cls = dpm_upper_deposition_limit_offset_cls
    """
    dpm_upper_deposition_limit_offset child of dpm.
    """
    dpm_deposition_delta_t: dpm_deposition_delta_t_cls = dpm_deposition_delta_t_cls
    """
    dpm_deposition_delta_t child of dpm.
    """
    dpm_laplace_number_constant: dpm_laplace_number_constant_cls = dpm_laplace_number_constant_cls
    """
    dpm_laplace_number_constant child of dpm.
    """
    dpm_partial_evaporation_ratio: dpm_partial_evaporation_ratio_cls = dpm_partial_evaporation_ratio_cls
    """
    dpm_partial_evaporation_ratio child of dpm.
    """
    ra_roughness: ra_roughness_cls = ra_roughness_cls
    """
    ra_roughness child of dpm.
    """
    rz_roughness: rz_roughness_cls = rz_roughness_cls
    """
    rz_roughness child of dpm.
    """
    rq_roughness: rq_roughness_cls = rq_roughness_cls
    """
    rq_roughness child of dpm.
    """
    rsm_roughness: rsm_roughness_cls = rsm_roughness_cls
    """
    rsm_roughness child of dpm.
    """
    enable_generic_erosion_model: enable_generic_erosion_model_cls = enable_generic_erosion_model_cls
    """
    enable_generic_erosion_model child of dpm.
    """
    generic_impact_angle_function: generic_impact_angle_function_cls = generic_impact_angle_function_cls
    """
    generic_impact_angle_function child of dpm.
    """
    generic_diameter_function: generic_diameter_function_cls = generic_diameter_function_cls
    """
    generic_diameter_function child of dpm.
    """
    generic_velocity_exponent_function: generic_velocity_exponent_function_cls = generic_velocity_exponent_function_cls
    """
    generic_velocity_exponent_function child of dpm.
    """
    enable_finnie_erosion_model: enable_finnie_erosion_model_cls = enable_finnie_erosion_model_cls
    """
    enable_finnie_erosion_model child of dpm.
    """
    dpm_bc_erosion_finnie_k: dpm_bc_erosion_finnie_k_cls = dpm_bc_erosion_finnie_k_cls
    """
    dpm_bc_erosion_finnie_k child of dpm.
    """
    dpm_bc_erosion_finnie_vel_exp: dpm_bc_erosion_finnie_vel_exp_cls = dpm_bc_erosion_finnie_vel_exp_cls
    """
    dpm_bc_erosion_finnie_vel_exp child of dpm.
    """
    dpm_bc_erosion_finnie_max_erosion_angle: dpm_bc_erosion_finnie_max_erosion_angle_cls = dpm_bc_erosion_finnie_max_erosion_angle_cls
    """
    dpm_bc_erosion_finnie_max_erosion_angle child of dpm.
    """
    dpm_bc_erosion_mclaury: dpm_bc_erosion_mclaury_cls = dpm_bc_erosion_mclaury_cls
    """
    dpm_bc_erosion_mclaury child of dpm.
    """
    dpm_bc_erosion_mclaury_a: dpm_bc_erosion_mclaury_a_cls = dpm_bc_erosion_mclaury_a_cls
    """
    dpm_bc_erosion_mclaury_a child of dpm.
    """
    dpm_bc_erosion_mclaury_vel_exp: dpm_bc_erosion_mclaury_vel_exp_cls = dpm_bc_erosion_mclaury_vel_exp_cls
    """
    dpm_bc_erosion_mclaury_vel_exp child of dpm.
    """
    dpm_bc_erosion_mclaury_transition_angle: dpm_bc_erosion_mclaury_transition_angle_cls = dpm_bc_erosion_mclaury_transition_angle_cls
    """
    dpm_bc_erosion_mclaury_transition_angle child of dpm.
    """
    dpm_bc_erosion_mclaury_b: dpm_bc_erosion_mclaury_b_cls = dpm_bc_erosion_mclaury_b_cls
    """
    dpm_bc_erosion_mclaury_b child of dpm.
    """
    dpm_bc_erosion_mclaury_c: dpm_bc_erosion_mclaury_c_cls = dpm_bc_erosion_mclaury_c_cls
    """
    dpm_bc_erosion_mclaury_c child of dpm.
    """
    dpm_bc_erosion_mclaury_w: dpm_bc_erosion_mclaury_w_cls = dpm_bc_erosion_mclaury_w_cls
    """
    dpm_bc_erosion_mclaury_w child of dpm.
    """
    dpm_bc_erosion_mclaury_x: dpm_bc_erosion_mclaury_x_cls = dpm_bc_erosion_mclaury_x_cls
    """
    dpm_bc_erosion_mclaury_x child of dpm.
    """
    dpm_bc_erosion_mclaury_y: dpm_bc_erosion_mclaury_y_cls = dpm_bc_erosion_mclaury_y_cls
    """
    dpm_bc_erosion_mclaury_y child of dpm.
    """
    dpm_bc_erosion_oka: dpm_bc_erosion_oka_cls = dpm_bc_erosion_oka_cls
    """
    dpm_bc_erosion_oka child of dpm.
    """
    dpm_bc_erosion_oka_e90: dpm_bc_erosion_oka_e90_cls = dpm_bc_erosion_oka_e90_cls
    """
    dpm_bc_erosion_oka_e90 child of dpm.
    """
    dpm_bc_erosion_oka_hv: dpm_bc_erosion_oka_hv_cls = dpm_bc_erosion_oka_hv_cls
    """
    dpm_bc_erosion_oka_hv child of dpm.
    """
    dpm_bc_erosion_oka_n1: dpm_bc_erosion_oka_n1_cls = dpm_bc_erosion_oka_n1_cls
    """
    dpm_bc_erosion_oka_n1 child of dpm.
    """
    dpm_bc_erosion_oka_n2: dpm_bc_erosion_oka_n2_cls = dpm_bc_erosion_oka_n2_cls
    """
    dpm_bc_erosion_oka_n2 child of dpm.
    """
    dpm_bc_erosion_oka_k2: dpm_bc_erosion_oka_k2_cls = dpm_bc_erosion_oka_k2_cls
    """
    dpm_bc_erosion_oka_k2 child of dpm.
    """
    dpm_bc_erosion_oka_k3: dpm_bc_erosion_oka_k3_cls = dpm_bc_erosion_oka_k3_cls
    """
    dpm_bc_erosion_oka_k3 child of dpm.
    """
    dpm_bc_erosion_oka_dref: dpm_bc_erosion_oka_dref_cls = dpm_bc_erosion_oka_dref_cls
    """
    dpm_bc_erosion_oka_dref child of dpm.
    """
    dpm_bc_erosion_oka_vref: dpm_bc_erosion_oka_vref_cls = dpm_bc_erosion_oka_vref_cls
    """
    dpm_bc_erosion_oka_vref child of dpm.
    """
    dpm_bc_erosion_dnv: dpm_bc_erosion_dnv_cls = dpm_bc_erosion_dnv_cls
    """
    dpm_bc_erosion_dnv child of dpm.
    """
    dpm_bc_erosion_dnv_k: dpm_bc_erosion_dnv_k_cls = dpm_bc_erosion_dnv_k_cls
    """
    dpm_bc_erosion_dnv_k child of dpm.
    """
    dpm_bc_erosion_dnv_n: dpm_bc_erosion_dnv_n_cls = dpm_bc_erosion_dnv_n_cls
    """
    dpm_bc_erosion_dnv_n child of dpm.
    """
    dpm_bc_erosion_dnv_ductile: dpm_bc_erosion_dnv_ductile_cls = dpm_bc_erosion_dnv_ductile_cls
    """
    dpm_bc_erosion_dnv_ductile child of dpm.
    """
    dpm_bc_erosion_shear: dpm_bc_erosion_shear_cls = dpm_bc_erosion_shear_cls
    """
    dpm_bc_erosion_shear child of dpm.
    """
    dpm_bc_erosion_shear_v: dpm_bc_erosion_shear_v_cls = dpm_bc_erosion_shear_v_cls
    """
    dpm_bc_erosion_shear_v child of dpm.
    """
    dpm_bc_erosion_shear_c: dpm_bc_erosion_shear_c_cls = dpm_bc_erosion_shear_c_cls
    """
    dpm_bc_erosion_shear_c child of dpm.
    """
    dpm_bc_erosion_shear_packing_limit: dpm_bc_erosion_shear_packing_limit_cls = dpm_bc_erosion_shear_packing_limit_cls
    """
    dpm_bc_erosion_shear_packing_limit child of dpm.
    """
    dpm_bc_erosion_shielding: dpm_bc_erosion_shielding_cls = dpm_bc_erosion_shielding_cls
    """
    dpm_bc_erosion_shielding child of dpm.
    """
    dpm_wall_heat_exchange: dpm_wall_heat_exchange_cls = dpm_wall_heat_exchange_cls
    """
    dpm_wall_heat_exchange child of dpm.
    """
    dpm_film_condensation: dpm_film_condensation_cls = dpm_film_condensation_cls
    """
    dpm_film_condensation child of dpm.
    """
    dpm_film_bl_model: dpm_film_bl_model_cls = dpm_film_bl_model_cls
    """
    dpm_film_bl_model child of dpm.
    """
    dpm_particle_stripping: dpm_particle_stripping_cls = dpm_particle_stripping_cls
    """
    dpm_particle_stripping child of dpm.
    """
    dpm_critical_shear_stress: dpm_critical_shear_stress_cls = dpm_critical_shear_stress_cls
    """
    dpm_critical_shear_stress child of dpm.
    """
    dpm_film_separation_model: dpm_film_separation_model_cls = dpm_film_separation_model_cls
    """
    dpm_film_separation_model child of dpm.
    """
    dpm_critical_we_number: dpm_critical_we_number_cls = dpm_critical_we_number_cls
    """
    dpm_critical_we_number child of dpm.
    """
    dpm_film_separation_angle: dpm_film_separation_angle_cls = dpm_film_separation_angle_cls
    """
    dpm_film_separation_angle child of dpm.
    """
    dpm_allow_lwf_to_vof: dpm_allow_lwf_to_vof_cls = dpm_allow_lwf_to_vof_cls
    """
    dpm_allow_lwf_to_vof child of dpm.
    """
    dpm_allow_vof_to_lwf: dpm_allow_vof_to_lwf_cls = dpm_allow_vof_to_lwf_cls
    """
    dpm_allow_vof_to_lwf child of dpm.
    """
    dpm_initialize_lwf: dpm_initialize_lwf_cls = dpm_initialize_lwf_cls
    """
    dpm_initialize_lwf child of dpm.
    """
    dpm_initial_height: dpm_initial_height_cls = dpm_initial_height_cls
    """
    dpm_initial_height child of dpm.
    """
    film_velocity: film_velocity_cls = film_velocity_cls
    """
    film_velocity child of dpm.
    """
    dpm_initial_temperature: dpm_initial_temperature_cls = dpm_initial_temperature_cls
    """
    dpm_initial_temperature child of dpm.
    """
    dpm_initial_injection: dpm_initial_injection_cls = dpm_initial_injection_cls
    """
    dpm_initial_injection child of dpm.
    """
    film_parcel_surface_area_density: film_parcel_surface_area_density_cls = film_parcel_surface_area_density_cls
    """
    film_parcel_surface_area_density child of dpm.
    """
    minimum_number_of_parcels_per_face: minimum_number_of_parcels_per_face_cls = minimum_number_of_parcels_per_face_cls
    """
    minimum_number_of_parcels_per_face child of dpm.
    """
    in_situ_data_reduction: in_situ_data_reduction_cls = in_situ_data_reduction_cls
    """
    in_situ_data_reduction child of dpm.
    """
    data_reduction: data_reduction_cls = data_reduction_cls
    """
    data_reduction child of dpm.
    """
    set_as_eulerian_film_wall: set_as_eulerian_film_wall_cls = set_as_eulerian_film_wall_cls
    """
    set_as_eulerian_film_wall child of dpm.
    """
    film_condition_type: film_condition_type_cls = film_condition_type_cls
    """
    film_condition_type child of dpm.
    """
    film_height: film_height_cls = film_height_cls
    """
    film_height child of dpm.
    """
    flux_momentum: flux_momentum_cls = flux_momentum_cls
    """
    flux_momentum child of dpm.
    """
    relative_initial_film_velocity: relative_initial_film_velocity_cls = relative_initial_film_velocity_cls
    """
    relative_initial_film_velocity child of dpm.
    """
    include_film_momentum_pressure: include_film_momentum_pressure_cls = include_film_momentum_pressure_cls
    """
    include_film_momentum_pressure child of dpm.
    """
    film_temperature: film_temperature_cls = film_temperature_cls
    """
    film_temperature child of dpm.
    """
    film_passive_scalar: film_passive_scalar_cls = film_passive_scalar_cls
    """
    film_passive_scalar child of dpm.
    """
    enable_film_source_terms: enable_film_source_terms_cls = enable_film_source_terms_cls
    """
    enable_film_source_terms child of dpm.
    """
    film_mass_source: film_mass_source_cls = film_mass_source_cls
    """
    film_mass_source child of dpm.
    """
    momentum_source: momentum_source_cls = momentum_source_cls
    """
    momentum_source child of dpm.
    """
    film_heat_source: film_heat_source_cls = film_heat_source_cls
    """
    film_heat_source child of dpm.
    """
    film_passive_scalar_source: film_passive_scalar_source_cls = film_passive_scalar_source_cls
    """
    film_passive_scalar_source child of dpm.
    """
    enable_film_phase_change: enable_film_phase_change_cls = enable_film_phase_change_cls
    """
    enable_film_phase_change child of dpm.
    """
    phase_change_model: phase_change_model_cls = phase_change_model_cls
    """
    phase_change_model child of dpm.
    """
    film_condensation_constant: film_condensation_constant_cls = film_condensation_constant_cls
    """
    film_condensation_constant child of dpm.
    """
    film_vaporization_constant: film_vaporization_constant_cls = film_vaporization_constant_cls
    """
    film_vaporization_constant child of dpm.
    """
    film_condensation_rate: film_condensation_rate_cls = film_condensation_rate_cls
    """
    film_condensation_rate child of dpm.
    """
    film_vaporization_rate: film_vaporization_rate_cls = film_vaporization_rate_cls
    """
    film_vaporization_rate child of dpm.
    """
    enable_flow_momentum_coupling: enable_flow_momentum_coupling_cls = enable_flow_momentum_coupling_cls
    """
    enable_flow_momentum_coupling child of dpm.
    """
    enable_dpm_wall_splash: enable_dpm_wall_splash_cls = enable_dpm_wall_splash_cls
    """
    enable_dpm_wall_splash child of dpm.
    """
    allow_film_boundary_separation: allow_film_boundary_separation_cls = allow_film_boundary_separation_cls
    """
    allow_film_boundary_separation child of dpm.
    """
    impingement_model: impingement_model_cls = impingement_model_cls
    """
    impingement_model child of dpm.
    """
    number_of_splashed_particles: number_of_splashed_particles_cls = number_of_splashed_particles_cls
    """
    number_of_splashed_particles child of dpm.
    """
    critical_temperature_factor: critical_temperature_factor_cls = critical_temperature_factor_cls
    """
    critical_temperature_factor child of dpm.
    """
    wall_roughness_length_ra: wall_roughness_length_ra_cls = wall_roughness_length_ra_cls
    """
    wall_roughness_length_ra child of dpm.
    """
    wall_roughness_length_rz: wall_roughness_length_rz_cls = wall_roughness_length_rz_cls
    """
    wall_roughness_length_rz child of dpm.
    """
    upper_deposition_limit_offset: upper_deposition_limit_offset_cls = upper_deposition_limit_offset_cls
    """
    upper_deposition_limit_offset child of dpm.
    """
    deposition_delta_t: deposition_delta_t_cls = deposition_delta_t_cls
    """
    deposition_delta_t child of dpm.
    """
    laplace_number_constant: laplace_number_constant_cls = laplace_number_constant_cls
    """
    laplace_number_constant child of dpm.
    """
    partial_evaporation_ratio: partial_evaporation_ratio_cls = partial_evaporation_ratio_cls
    """
    partial_evaporation_ratio child of dpm.
    """
    enable_film_contact_angle_force: enable_film_contact_angle_force_cls = enable_film_contact_angle_force_cls
    """
    enable_film_contact_angle_force child of dpm.
    """
    film_contact_angle_mean: film_contact_angle_mean_cls = film_contact_angle_mean_cls
    """
    film_contact_angle_mean child of dpm.
    """
    film_contact_angle_rstd: film_contact_angle_rstd_cls = film_contact_angle_rstd_cls
    """
    film_contact_angle_rstd child of dpm.
    """
    film_contact_angle_beta: film_contact_angle_beta_cls = film_contact_angle_beta_cls
    """
    film_contact_angle_beta child of dpm.
    """
    film_vof_coupling_high: film_vof_coupling_high_cls = film_vof_coupling_high_cls
    """
    film_vof_coupling_high child of dpm.
    """
    film_vof_trans_high: film_vof_trans_high_cls = film_vof_trans_high_cls
    """
    film_vof_trans_high child of dpm.
    """
    film_vof_trans_high_relax: film_vof_trans_high_relax_cls = film_vof_trans_high_relax_cls
    """
    film_vof_trans_high_relax child of dpm.
    """
    film_vof_coupling_low: film_vof_coupling_low_cls = film_vof_coupling_low_cls
    """
    film_vof_coupling_low child of dpm.
    """
    film_vof_trans_low: film_vof_trans_low_cls = film_vof_trans_low_cls
    """
    film_vof_trans_low child of dpm.
    """
    film_vof_trans_low_relax: film_vof_trans_low_relax_cls = film_vof_trans_low_relax_cls
    """
    film_vof_trans_low_relax child of dpm.
    """
    command_names = \
        ['dpm_do_initialize_lwf_now']

    dpm_do_initialize_lwf_now: dpm_do_initialize_lwf_now_cls = dpm_do_initialize_lwf_now_cls
    """
    dpm_do_initialize_lwf_now command of dpm.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .verbosity_option import verbosity_option as verbosity_option_cls
class mphase_summary(Command):
    """
    Multiphase Summary and Recommendations.
    
    Parameters
    ----------
        verbosity_option : str
            'verbosity_option' child.
    
    """

    fluent_name = "mphase-summary"

    argument_names = \
        ['verbosity_option']

    verbosity_option: verbosity_option_cls = verbosity_option_cls
    """
    verbosity_option argument of mphase_summary.
    """



import time

import pytest

from ansys.fluent.core.utils.execution import (
    InvalidArgument,
    timeout_exec,
    timeout_loop,
)


def test_timeout_exec():
    ret = timeout_exec(time.sleep, timeout=0.25, args=(0.5,))
    assert ret is False
    ret = timeout_exec(time.sleep, timeout=0.5, args=(0.25,))
    assert ret is True


def test_timeout_loop():
    class ExpectedAfterFive:
        def __init__(self, expected):
            self._counter = 0
            self._expected = expected

        def __call__(self):
            self._counter += 1
            if self._counter >= 5:
                return self._expected
            else:
                return not self._expected

    class Waiter:
        def __init__(self, func, expected):
            self._func = func(expected)
            self._expected = expected

        def __call__(self):
            returned = self._func()
            if returned == self._expected:
                return returned
            else:
                return returned

    waiter = Waiter(ExpectedAfterFive, expected=True)
    ret = timeout_loop(waiter, timeout=1, expected="truthy", idle_period=0.1)
    assert ret is True

    waiter = Waiter(ExpectedAfterFive, expected=False)
    ret = timeout_loop(waiter, timeout=1, expected="falsy", idle_period=0.1)
    assert ret is False

    waiter = Waiter(ExpectedAfterFive, expected=True)
    ret = timeout_loop(waiter, timeout=0.2, expected="truthy", idle_period=0.1)
    assert ret is False

    with pytest.raises(InvalidArgument) as msg:
        timeout_loop(waiter, timeout=0.2, expected=True, idle_period=0.1)


def count_key_recursive(dictionary, key):
    count = 0
    for k, v in dictionary.items():
        if k == key:
            count += 1
        elif isinstance(v, dict):
            count += count_key_recursive(v, key)
    return count



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .reference_frame_2 import reference_frame as reference_frame_cls
from .gauge_total_pressure import gauge_total_pressure as gauge_total_pressure_cls
from .supersonic_or_initial_gauge_pressure import supersonic_or_initial_gauge_pressure as supersonic_or_initial_gauge_pressure_cls
from .direction_specification_method import direction_specification_method as direction_specification_method_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .direction_vector import direction_vector as direction_vector_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .prevent_reverse_flow import prevent_reverse_flow as prevent_reverse_flow_cls
from .ac_options import ac_options as ac_options_cls
from .impedance_0 import impedance_0 as impedance_0_cls
from .impedance_1 import impedance_1 as impedance_1_cls
from .impedance_2 import impedance_2 as impedance_2_cls
from .ac_wave import ac_wave as ac_wave_cls
class momentum(Group):
    """
    Help not available.
    """

    fluent_name = "momentum"

    child_names = \
        ['reference_frame', 'gauge_total_pressure',
         'supersonic_or_initial_gauge_pressure',
         'direction_specification_method', 'coordinate_system',
         'flow_direction', 'direction_vector', 'axis_direction',
         'axis_origin', 'prevent_reverse_flow', 'ac_options', 'impedance_0',
         'impedance_1', 'impedance_2', 'ac_wave']

    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of momentum.
    """
    gauge_total_pressure: gauge_total_pressure_cls = gauge_total_pressure_cls
    """
    gauge_total_pressure child of momentum.
    """
    supersonic_or_initial_gauge_pressure: supersonic_or_initial_gauge_pressure_cls = supersonic_or_initial_gauge_pressure_cls
    """
    supersonic_or_initial_gauge_pressure child of momentum.
    """
    direction_specification_method: direction_specification_method_cls = direction_specification_method_cls
    """
    direction_specification_method child of momentum.
    """
    coordinate_system: coordinate_system_cls = coordinate_system_cls
    """
    coordinate_system child of momentum.
    """
    flow_direction: flow_direction_cls = flow_direction_cls
    """
    flow_direction child of momentum.
    """
    direction_vector: direction_vector_cls = direction_vector_cls
    """
    direction_vector child of momentum.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of momentum.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of momentum.
    """
    prevent_reverse_flow: prevent_reverse_flow_cls = prevent_reverse_flow_cls
    """
    prevent_reverse_flow child of momentum.
    """
    ac_options: ac_options_cls = ac_options_cls
    """
    ac_options child of momentum.
    """
    impedance_0: impedance_0_cls = impedance_0_cls
    """
    impedance_0 child of momentum.
    """
    impedance_1: impedance_1_cls = impedance_1_cls
    """
    impedance_1 child of momentum.
    """
    impedance_2: impedance_2_cls = impedance_2_cls
    """
    impedance_2 child of momentum.
    """
    ac_wave: ac_wave_cls = ac_wave_cls
    """
    ac_wave child of momentum.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class display_clipped_pressure(Boolean):
    """
    Clipped pressure is just used for the properties evaluation. Mass Transfer Rate uses unclipped pressure.
    """

    fluent_name = "display-clipped-pressure?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class capture_simulation_report_data(Boolean):
    """
    Capture Simulation Report Data option for Design Point.
    """

    fluent_name = "capture-simulation-report-data"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .controls import controls as controls_cls
from .methods_1 import methods as methods_cls
from .report_definitions import report_definitions as report_definitions_cls
from .initialization import initialization as initialization_cls
from .run_calculation import run_calculation as run_calculation_cls
class solution(Group):
    """
    'solution' child.
    """

    fluent_name = "solution"

    child_names = \
        ['controls', 'methods', 'report_definitions', 'initialization',
         'run_calculation']

    controls: controls_cls = controls_cls
    """
    controls child of solution.
    """
    methods: methods_cls = methods_cls
    """
    methods child of solution.
    """
    report_definitions: report_definitions_cls = report_definitions_cls
    """
    report_definitions child of solution.
    """
    initialization: initialization_cls = initialization_cls
    """
    initialization child of solution.
    """
    run_calculation: run_calculation_cls = run_calculation_cls
    """
    run_calculation child of solution.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .entropic_heat_enabled import entropic_heat_enabled as entropic_heat_enabled_cls
from .data_type_1 import data_type as data_type_cls
from .two_tables import two_tables as two_tables_cls
from .table_discharge import table_discharge as table_discharge_cls
from .table_charge import table_charge as table_charge_cls
from .udf_name import udf_name as udf_name_cls
class entropic_heat(Group):
    """
    'entropic_heat' child.
    """

    fluent_name = "entropic-heat"

    child_names = \
        ['entropic_heat_enabled', 'data_type', 'two_tables',
         'table_discharge', 'table_charge', 'udf_name']

    entropic_heat_enabled: entropic_heat_enabled_cls = entropic_heat_enabled_cls
    """
    entropic_heat_enabled child of entropic_heat.
    """
    data_type: data_type_cls = data_type_cls
    """
    data_type child of entropic_heat.
    """
    two_tables: two_tables_cls = two_tables_cls
    """
    two_tables child of entropic_heat.
    """
    table_discharge: table_discharge_cls = table_discharge_cls
    """
    table_discharge child of entropic_heat.
    """
    table_charge: table_charge_cls = table_charge_cls
    """
    table_charge child of entropic_heat.
    """
    udf_name: udf_name_cls = udf_name_cls
    """
    udf_name child of entropic_heat.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .north_x import north_x as north_x_cls
from .north_y import north_y as north_y_cls
from .north_z import north_z as north_z_cls
class north_direction(Group):
    """
    'north_direction' child.
    """

    fluent_name = "north-direction"

    child_names = \
        ['north_x', 'north_y', 'north_z']

    north_x: north_x_cls = north_x_cls
    """
    north_x child of north_direction.
    """
    north_y: north_y_cls = north_y_cls
    """
    north_y child of north_direction.
    """
    north_z: north_z_cls = north_z_cls
    """
    north_z child of north_direction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .lower import lower as lower_cls
from .upper import upper as upper_cls
class outside_std_dev(Group):
    """
    'outside_std_dev' child.
    """

    fluent_name = "outside-std-dev"

    child_names = \
        ['lower', 'upper']

    lower: lower_cls = lower_cls
    """
    lower child of outside_std_dev.
    """
    upper: upper_cls = upper_cls
    """
    upper child of outside_std_dev.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_21 import phase as phase_cls
from .name_1 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .pid import pid as pid_cls
from .temperature_spec import temperature_spec as temperature_spec_cls
from .temperature_rise import temperature_rise as temperature_rise_cls
from .heat_source import heat_source as heat_source_cls
from .tinf import tinf as tinf_cls
from .hc import hc as hc_cls
from .direction_spec import direction_spec as direction_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .direction_vector import direction_vector as direction_vector_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e_1 import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .mass_flow_multiplier import mass_flow_multiplier as mass_flow_multiplier_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
class recirculation_inlet_child(Group):
    """
    'child_object_type' of recirculation_inlet.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x',
         'geom_dir_y', 'geom_dir_z', 'geom_levels', 'geom_bgthread', 'pid',
         'temperature_spec', 'temperature_rise', 'heat_source', 'tinf', 'hc',
         'direction_spec', 'coordinate_system', 'flow_direction',
         'direction_vector', 'ke_spec', 'nut', 'kl', 'intermit', 'k', 'e',
         'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'mass_flow_multiplier', 'solar_fluxes', 'solar_shining_factor']

    phase: phase_cls = phase_cls
    """
    phase child of recirculation_inlet_child.
    """
    name: name_cls = name_cls
    """
    name child of recirculation_inlet_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of recirculation_inlet_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of recirculation_inlet_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of recirculation_inlet_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of recirculation_inlet_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of recirculation_inlet_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of recirculation_inlet_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of recirculation_inlet_child.
    """
    pid: pid_cls = pid_cls
    """
    pid child of recirculation_inlet_child.
    """
    temperature_spec: temperature_spec_cls = temperature_spec_cls
    """
    temperature_spec child of recirculation_inlet_child.
    """
    temperature_rise: temperature_rise_cls = temperature_rise_cls
    """
    temperature_rise child of recirculation_inlet_child.
    """
    heat_source: heat_source_cls = heat_source_cls
    """
    heat_source child of recirculation_inlet_child.
    """
    tinf: tinf_cls = tinf_cls
    """
    tinf child of recirculation_inlet_child.
    """
    hc: hc_cls = hc_cls
    """
    hc child of recirculation_inlet_child.
    """
    direction_spec: direction_spec_cls = direction_spec_cls
    """
    direction_spec child of recirculation_inlet_child.
    """
    coordinate_system: coordinate_system_cls = coordinate_system_cls
    """
    coordinate_system child of recirculation_inlet_child.
    """
    flow_direction: flow_direction_cls = flow_direction_cls
    """
    flow_direction child of recirculation_inlet_child.
    """
    direction_vector: direction_vector_cls = direction_vector_cls
    """
    direction_vector child of recirculation_inlet_child.
    """
    ke_spec: ke_spec_cls = ke_spec_cls
    """
    ke_spec child of recirculation_inlet_child.
    """
    nut: nut_cls = nut_cls
    """
    nut child of recirculation_inlet_child.
    """
    kl: kl_cls = kl_cls
    """
    kl child of recirculation_inlet_child.
    """
    intermit: intermit_cls = intermit_cls
    """
    intermit child of recirculation_inlet_child.
    """
    k: k_cls = k_cls
    """
    k child of recirculation_inlet_child.
    """
    e: e_cls = e_cls
    """
    e child of recirculation_inlet_child.
    """
    o: o_cls = o_cls
    """
    o child of recirculation_inlet_child.
    """
    v2: v2_cls = v2_cls
    """
    v2 child of recirculation_inlet_child.
    """
    turb_intensity: turb_intensity_cls = turb_intensity_cls
    """
    turb_intensity child of recirculation_inlet_child.
    """
    turb_length_scale: turb_length_scale_cls = turb_length_scale_cls
    """
    turb_length_scale child of recirculation_inlet_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam_cls = turb_hydraulic_diam_cls
    """
    turb_hydraulic_diam child of recirculation_inlet_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio_cls = turb_viscosity_ratio_cls
    """
    turb_viscosity_ratio child of recirculation_inlet_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile_cls = turb_viscosity_ratio_profile_cls
    """
    turb_viscosity_ratio_profile child of recirculation_inlet_child.
    """
    rst_spec: rst_spec_cls = rst_spec_cls
    """
    rst_spec child of recirculation_inlet_child.
    """
    uu: uu_cls = uu_cls
    """
    uu child of recirculation_inlet_child.
    """
    vv: vv_cls = vv_cls
    """
    vv child of recirculation_inlet_child.
    """
    ww: ww_cls = ww_cls
    """
    ww child of recirculation_inlet_child.
    """
    uv: uv_cls = uv_cls
    """
    uv child of recirculation_inlet_child.
    """
    vw: vw_cls = vw_cls
    """
    vw child of recirculation_inlet_child.
    """
    uw: uw_cls = uw_cls
    """
    uw child of recirculation_inlet_child.
    """
    ksgs_spec: ksgs_spec_cls = ksgs_spec_cls
    """
    ksgs_spec child of recirculation_inlet_child.
    """
    ksgs: ksgs_cls = ksgs_cls
    """
    ksgs child of recirculation_inlet_child.
    """
    sgs_turb_intensity: sgs_turb_intensity_cls = sgs_turb_intensity_cls
    """
    sgs_turb_intensity child of recirculation_inlet_child.
    """
    mass_flow_multiplier: mass_flow_multiplier_cls = mass_flow_multiplier_cls
    """
    mass_flow_multiplier child of recirculation_inlet_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of recirculation_inlet_child.
    """
    solar_shining_factor: solar_shining_factor_cls = solar_shining_factor_cls
    """
    solar_shining_factor child of recirculation_inlet_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .isat_error_tolerance import isat_error_tolerance as isat_error_tolerance_cls
from .isat_table_size import isat_table_size as isat_table_size_cls
from .isat_verbosity import isat_verbosity as isat_verbosity_cls
from .clear_isat_table import clear_isat_table as clear_isat_table_cls
class isat_options(Group):
    """
    'isat_options' child.
    """

    fluent_name = "isat-options"

    child_names = \
        ['isat_error_tolerance', 'isat_table_size', 'isat_verbosity']

    isat_error_tolerance: isat_error_tolerance_cls = isat_error_tolerance_cls
    """
    isat_error_tolerance child of isat_options.
    """
    isat_table_size: isat_table_size_cls = isat_table_size_cls
    """
    isat_table_size child of isat_options.
    """
    isat_verbosity: isat_verbosity_cls = isat_verbosity_cls
    """
    isat_verbosity child of isat_options.
    """
    command_names = \
        ['clear_isat_table']

    clear_isat_table: clear_isat_table_cls = clear_isat_table_cls
    """
    clear_isat_table command of isat_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_2 import list as list_cls
from .list_properties_5 import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .set_1 import set as set_cls
from .register_based_child import register_based_child

class register_based(NamedObject[register_based_child], _CreatableNamedObjectMixin[register_based_child]):
    """
    Set up the application of poor mesh numerics to cells in a register.
    """

    fluent_name = "register-based"

    command_names = \
        ['list', 'list_properties', 'duplicate', 'set']

    list: list_cls = list_cls
    """
    list command of register_based.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of register_based.
    """
    duplicate: duplicate_cls = duplicate_cls
    """
    duplicate command of register_based.
    """
    set: set_cls = set_cls
    """
    set command of register_based.
    """
    child_object_type: register_based_child = register_based_child
    """
    child_object_type of register_based.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_type import report_type as report_type_cls
from .surface_id import surface_id as surface_id_cls
from .add_custome_vector import add_custome_vector as add_custome_vector_cls
from .cust_vec_name import cust_vec_name as cust_vec_name_cls
from .domain_cx import domain_cx as domain_cx_cls
from .cell_cx import cell_cx as cell_cx_cls
from .domain_cy import domain_cy as domain_cy_cls
from .cell_cy import cell_cy as cell_cy_cls
from .domain_cz import domain_cz as domain_cz_cls
from .cell_cz import cell_cz as cell_cz_cls
from .cust_vec_func import cust_vec_func as cust_vec_func_cls
from .domain_report import domain_report as domain_report_cls
from .cell_report import cell_report as cell_report_cls
from .current_domain import current_domain as current_domain_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls
class surface_integrals(Command):
    """
    'surface_integrals' command.
    
    Parameters
    ----------
        report_type : str
            'report_type' child.
        surface_id : typing.List[str]
            'surface_id' child.
        add_custome_vector : bool
            'add_custome_vector' child.
        cust_vec_name : str
            'cust_vec_name' child.
        domain_cx : str
            'domain_cx' child.
        cell_cx : str
            'cell_cx' child.
        domain_cy : str
            'domain_cy' child.
        cell_cy : str
            'cell_cy' child.
        domain_cz : str
            'domain_cz' child.
        cell_cz : str
            'cell_cz' child.
        cust_vec_func : str
            'cust_vec_func' child.
        domain_report : str
            'domain_report' child.
        cell_report : str
            'cell_report' child.
        current_domain : str
            'current_domain' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "surface-integrals"

    argument_names = \
        ['report_type', 'surface_id', 'add_custome_vector', 'cust_vec_name',
         'domain_cx', 'cell_cx', 'domain_cy', 'cell_cy', 'domain_cz',
         'cell_cz', 'cust_vec_func', 'domain_report', 'cell_report',
         'current_domain', 'write_to_file', 'file_name', 'append_data',
         'overwrite']

    report_type: report_type_cls = report_type_cls
    """
    report_type argument of surface_integrals.
    """
    surface_id: surface_id_cls = surface_id_cls
    """
    surface_id argument of surface_integrals.
    """
    add_custome_vector: add_custome_vector_cls = add_custome_vector_cls
    """
    add_custome_vector argument of surface_integrals.
    """
    cust_vec_name: cust_vec_name_cls = cust_vec_name_cls
    """
    cust_vec_name argument of surface_integrals.
    """
    domain_cx: domain_cx_cls = domain_cx_cls
    """
    domain_cx argument of surface_integrals.
    """
    cell_cx: cell_cx_cls = cell_cx_cls
    """
    cell_cx argument of surface_integrals.
    """
    domain_cy: domain_cy_cls = domain_cy_cls
    """
    domain_cy argument of surface_integrals.
    """
    cell_cy: cell_cy_cls = cell_cy_cls
    """
    cell_cy argument of surface_integrals.
    """
    domain_cz: domain_cz_cls = domain_cz_cls
    """
    domain_cz argument of surface_integrals.
    """
    cell_cz: cell_cz_cls = cell_cz_cls
    """
    cell_cz argument of surface_integrals.
    """
    cust_vec_func: cust_vec_func_cls = cust_vec_func_cls
    """
    cust_vec_func argument of surface_integrals.
    """
    domain_report: domain_report_cls = domain_report_cls
    """
    domain_report argument of surface_integrals.
    """
    cell_report: cell_report_cls = cell_report_cls
    """
    cell_report argument of surface_integrals.
    """
    current_domain: current_domain_cls = current_domain_cls
    """
    current_domain argument of surface_integrals.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of surface_integrals.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of surface_integrals.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of surface_integrals.
    """
    overwrite: overwrite_cls = overwrite_cls
    """
    overwrite argument of surface_integrals.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .pseudo_time_courant_number import pseudo_time_courant_number as pseudo_time_courant_number_cls
from .pseudo_time_step_method_solid_zone import pseudo_time_step_method_solid_zone as pseudo_time_step_method_solid_zone_cls
from .time_step_size_scale_factor import time_step_size_scale_factor as time_step_size_scale_factor_cls
class local_time_step_settings(Group):
    """
    'local_time_step_settings' child.
    """

    fluent_name = "local-time-step-settings"

    child_names = \
        ['pseudo_time_courant_number', 'pseudo_time_step_method_solid_zone',
         'time_step_size_scale_factor']

    pseudo_time_courant_number: pseudo_time_courant_number_cls = pseudo_time_courant_number_cls
    """
    pseudo_time_courant_number child of local_time_step_settings.
    """
    pseudo_time_step_method_solid_zone: pseudo_time_step_method_solid_zone_cls = pseudo_time_step_method_solid_zone_cls
    """
    pseudo_time_step_method_solid_zone child of local_time_step_settings.
    """
    time_step_size_scale_factor: time_step_size_scale_factor_cls = time_step_size_scale_factor_cls
    """
    time_step_size_scale_factor child of local_time_step_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class pseudo_time_method:
    fluent_name = ...
    child_names = ...
    formulation = ...
    relaxation_method = ...
    convergence_acceleration_for_stretched_meshes = ...
    command_names = ...

    def relaxation_bounds(self, relaxation_bounding_method: str, default_min_max_relaxation_limits: bool, minimum_allowed_effctive_relaxation: Union[float, str], maximum_allowed_effctive_relaxation: Union[float, str]):
        """
        Select relaxation bounding scheme for pseudo time method.
        
        Parameters
        ----------
            relaxation_bounding_method : str
                'relaxation_bounding_method' child.
            default_min_max_relaxation_limits : bool
                'default_min_max_relaxation_limits' child.
            minimum_allowed_effctive_relaxation : real
                'minimum_allowed_effctive_relaxation' child.
            maximum_allowed_effctive_relaxation : real
                'maximum_allowed_effctive_relaxation' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .object_name import object_name as object_name_cls
class list_properties(Command):
    """
    List active properties of the object.
    
    Parameters
    ----------
        object_name : str
            Select object for which properties are to be listed.
    
    """

    fluent_name = "list-properties"

    argument_names = \
        ['object_name']

    object_name: object_name_cls = object_name_cls
    """
    object_name argument of list_properties.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .report_type import report_type as report_type_cls
from .geometry_4 import geometry as geometry_cls
from .physics_1 import physics as physics_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .phase_25 import phase as phase_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
from .old_props import old_props as old_props_cls
from .zone_names_1 import zone_names as zone_names_cls
from .zone_ids import zone_ids as zone_ids_cls
class flux_child(Group):
    """
    'child_object_type' of flux.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'report_type', 'geometry', 'physics',
         'retain_instantaneous_values', 'phase', 'average_over', 'per_zone',
         'old_props', 'zone_names', 'zone_ids']

    name: name_cls = name_cls
    """
    name child of flux_child.
    """
    report_type: report_type_cls = report_type_cls
    """
    report_type child of flux_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of flux_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of flux_child.
    """
    retain_instantaneous_values: retain_instantaneous_values_cls = retain_instantaneous_values_cls
    """
    retain_instantaneous_values child of flux_child.
    """
    phase: phase_cls = phase_cls
    """
    phase child of flux_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of flux_child.
    """
    per_zone: per_zone_cls = per_zone_cls
    """
    per_zone child of flux_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of flux_child.
    """
    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names child of flux_child.
    """
    zone_ids: zone_ids_cls = zone_ids_cls
    """
    zone_ids child of flux_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class direction_vector:
    fluent_name = ...
    command_names = ...

    def list_properties(self, object_at: int):
        """
        List properties of selected object.
        
        Parameters
        ----------
            object_at : int
                Select object index to delete.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class execute_commands:
    fluent_name = ...
    command_names = ...

    def enable(self, command_name: str):
        """
        Enable an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def disable(self, command_name: str):
        """
        Disable an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def copy(self, command_name: str):
        """
        Copy an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def delete(self, command_name: str):
        """
        Delete an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def export(self, command_name: List[str], tsv_file_name: str):
        """
        Export execute-commands to a TSV file.
        
        Parameters
        ----------
            command_name : typing.List[str]
                'command_name' child.
            tsv_file_name : str
                'tsv_file_name' child.
        
        """

    def import_(self, tsv_file_name: str):
        """
        Import execute-commands from a TSV file.
        
        Parameters
        ----------
            tsv_file_name : str
                'tsv_file_name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class driver_options:
    fluent_name = ...
    child_names = ...
    hardcopy_format = ...
    hardcopy_options = ...
    window_dump_cmd = ...
    post_format = ...
    command_names = ...

    def current_driver(self, ):
        """
        'current_driver' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_names_4 import zone_names as zone_names_cls
class create_multiple_zone_surfaces(Command):
    """
    'create_multiple_zone_surfaces' command.
    
    Parameters
    ----------
        zone_names : typing.List[str]
            Enter zone name list.
    
    """

    fluent_name = "create-multiple-zone-surfaces"

    argument_names = \
        ['zone_names']

    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names argument of create_multiple_zone_surfaces.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .print_histogram import print_histogram as print_histogram_cls
from .write_histogram import write_histogram as write_histogram_cls
class print_write_histogram(Group):
    """
    'print_write_histogram' child.
    """

    fluent_name = "print-write-histogram"

    command_names = \
        ['print_histogram', 'write_histogram']

    print_histogram: print_histogram_cls = print_histogram_cls
    """
    print_histogram command of print_write_histogram.
    """
    write_histogram: write_histogram_cls = write_histogram_cls
    """
    write_histogram command of print_write_histogram.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .model_ramping import model_ramping as model_ramping_cls
from .ramp_flow import ramp_flow as ramp_flow_cls
from .ramp_turbulence import ramp_turbulence as ramp_turbulence_cls
from .ramp_scalars import ramp_scalars as ramp_scalars_cls
class models(Group):
    """
    'models' child.
    """

    fluent_name = "models"

    child_names = \
        ['model_ramping', 'ramp_flow', 'ramp_turbulence', 'ramp_scalars']

    model_ramping: model_ramping_cls = model_ramping_cls
    """
    model_ramping child of models.
    """
    ramp_flow: ramp_flow_cls = ramp_flow_cls
    """
    ramp_flow child of models.
    """
    ramp_turbulence: ramp_turbulence_cls = ramp_turbulence_cls
    """
    ramp_turbulence child of models.
    """
    ramp_scalars: ramp_scalars_cls = ramp_scalars_cls
    """
    ramp_scalars child of models.
    """



"""Module for monitors management."""

import threading
from typing import Dict, List, Optional, Tuple, Union

import numpy as np
import pandas as pd

from ansys.api.fluent.v0 import monitor_pb2 as MonitorModule
from ansys.fluent.core.streaming_services.streaming import StreamingService


class MonitorsManager(StreamingService):
    """Manages monitors (Fluent residuals and report definitions monitors).

    Parameters
    ----------
    session_id : str
        Session ID.
    service : MonitorsService
        Monitors streaming service.
    """

    def __init__(self, session_id: str, service):
        """__init__ method of MonitorsManager class."""
        super().__init__(
            stream_begin_method="BeginStreaming",
            target=MonitorsManager._process_streaming,
            streaming_service=service,
        )
        self._session_id: str = session_id
        self._lock_refresh: threading.Lock = threading.Lock()
        self._monitors_info = None
        self._data_frames = {}

    def get_monitor_set_names(self) -> List[str]:
        """Get monitor set names.

        Parameters
        ----------
        None

        Returns
        -------
        List[str]
            List of all monitor set names.
        """
        with self._lock:
            return list(self._data_frames)

    def get_monitor_set_prop(self, monitor_set_name: str, property: str) -> str:
        """Get monitor set property.

        Parameters
        ----------
        monitor_set_name : str
            Name of the monitor.
        property : str
            Property of the monitor set. It can be ``title``, ``xlabel``, or ``ylabel``.

        Returns
        -------
        str
            Monitor set property.
        """
        with self._lock:
            return self._monitors_info.get(monitor_set_name, {}).get(property)

    def get_monitor_set_plot(
        self, monitor_set_name, *args, **kwargs
    ) -> Union[None, object]:
        """Get monitor set plot.

        Parameters
        ----------
        monitor_set_name : str
            Name of the monitor.

        Returns
        -------
        Union[None, object]
            Returns ``None`` if the `DataFrame <https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.html>`_
            is empty. Otherwise, it returns the plot object, depending on the ``plotting.backend``.
        """
        with self._lock:
            df = self._data_frames[monitor_set_name]["df"]
            return None if df.empty else df.plot(*args, **kwargs)

    def get_monitor_set_data(
        self, monitor_set_name, start_index: int = 0, end_index: Optional[int] = None
    ) -> Tuple[np.array, Dict[str, np.array]]:
        """Get monitor set data.

        Parameters
        ----------
        monitor_set_name : str
            Name of the monitor set.
        start_index: int, optional
            Start index to provide data.
        end_index: int, optional
            End index to provide data.

        Returns
        -------
        Tuple[np.array, Dict[str, np.array]]
            Tuple containing two elements: a numpy array of x-axis values and a dictionary
            associating monitor names of type ``str`` to numpy arrays of y-axis values.
        """
        with self._lock:
            df_data = self._data_frames[monitor_set_name]
            try:
                df = df_data["df"].iloc[start_index:end_index]
            except IndexError:
                return (np.array([]), {})
            return (
                (np.array([]), {})
                if df.empty
                else (
                    df.index.to_numpy(),
                    {column: df[column].to_numpy() for column in df.columns},
                )
            )

    def refresh(self, session_id, event_info) -> None:
        """Refresh plots on-initialized and data-read events.

        This method is registered with the EventsManager and is called
        to refresh plots whenever on-initialized and data-read events occur.

        Parameters
        ----------
        session_id : str
            Name of the monitor set.
        event_info : object
            Event info object.

        Returns
        -------
        None
        """
        with self._lock_refresh:
            self.stop()
            self.start()

    def _prepare(self):
        self._update_dataframe()

    def _populate_dataframes(self, data_received, *args, **kwargs):
        for _, df_data in self._data_frames.items():
            df = df_data["df"]
            monitors = df_data["monitors"]
            monitor_data = []
            for monitor_name in monitors:
                if monitor_name not in data_received:
                    monitor_data = []
                    break
                monitor_data.append(data_received[monitor_name])

            if monitor_data:
                new_df = pd.DataFrame([monitor_data], columns=monitors)
                new_df.set_index("xvalues", inplace=True)
                if df.empty:
                    df_data["df"] = new_df
                else:
                    df_data["df"] = pd.concat([df, new_df])
                for callback_map in self._service_callbacks.values():
                    callback, args, kwargs = callback_map
                    callback(*args, **kwargs)

    def _process_streaming(self, id, stream_begin_method, started_evt, *args, **kwargs):
        """Begin monitors streaming."""
        request = MonitorModule.StreamingRequest(*args, **kwargs)
        responses = self._streaming_service.begin_streaming(
            request, started_evt, id=id, stream_begin_method=stream_begin_method
        )

        while True:
            try:
                data_received = {}
                response = next(responses)
                x_axis_type = response.xaxisdata.xaxistype
                x_axis_index = response.xaxisdata.xaxisindex
                data_received["xvalues"] = x_axis_index
                for y_axis_value in response.yaxisvalues:
                    data_received[y_axis_value.name] = y_axis_value.value
                with self._lock:
                    self._streaming = True
                    self._populate_dataframes(data_received, *args, **kwargs)

            except StopIteration:
                break

    def _update_dataframe(self):
        with self._lock:
            self._monitors_info = self._streaming_service.get_monitors_info()
            self._data_frames = {}
            for monitor_set_name, monitor_set_info in self._monitors_info.items():
                if "monitors" not in monitor_set_info:
                    continue
                self._data_frames[monitor_set_name] = {}
                monitors_name = list(monitor_set_info["monitors"]) + ["xvalues"]
                df = pd.DataFrame([], columns=monitors_name)
                df.set_index("xvalues", inplace=True)
                self._data_frames[monitor_set_name]["df"] = df
                self._data_frames[monitor_set_name]["monitors"] = monitors_name



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_14 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .angular import angular as angular_cls
from .p_jump import p_jump as p_jump_cls
class periodic_child(Group):
    """
    'child_object_type' of periodic.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'angular', 'p_jump']

    phase: phase_cls = phase_cls
    """
    phase child of periodic_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of periodic_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of periodic_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of periodic_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of periodic_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of periodic_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of periodic_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of periodic_child.
    """
    angular: angular_cls = angular_cls
    """
    angular child of periodic_child.
    """
    p_jump: p_jump_cls = p_jump_cls
    """
    p_jump child of periodic_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class patch:
    fluent_name = ...
    child_names = ...
    vof_smooth_options = ...
    command_names = ...

    def calculate_patch(self, domain: str, cell_zones: List[str], registers: List[str], variable: str, reference_frame: str, use_custom_field_function: bool, custom_field_function_name: str, value: Union[float, str]):
        """
        Patch a value for a flow variable in the domain.
        
        Parameters
        ----------
            domain : str
                Enter domain.
            cell_zones : typing.List[str]
                Enter cell zone.
            registers : typing.List[str]
                Enter register.
            variable : str
                Enter variable.
            reference_frame : str
                Select velocity Reference Frame.
            use_custom_field_function : bool
                Enable/disable custom field function for patching.
            custom_field_function_name : str
                Enter custom function.
            value : real
                Enter patch value.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_each_line import report_each_line as report_each_line_cls
class chemkin_report_each_line(Command):
    """
    'chemkin_report_each_line' command.
    
    Parameters
    ----------
        report_each_line : bool
            Enable/disable reporting after reading each line.
    
    """

    fluent_name = "chemkin-report-each-line?"

    argument_names = \
        ['report_each_line']

    report_each_line: report_each_line_cls = report_each_line_cls
    """
    report_each_line argument of chemkin_report_each_line.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .set_custom_frames_1 import set_custom_frames as set_custom_frames_cls
from .read_animation import read_animation as read_animation_cls
from .write_animation_1 import write_animation as write_animation_cls
from .add_keyframe import add_keyframe as add_keyframe_cls
from .delete_keyframe import delete_keyframe as delete_keyframe_cls
from .delete_all_keyframes import delete_all_keyframes as delete_all_keyframes_cls
from .play_1 import play as play_cls
class scene_animation(Group):
    """
    Keyframe animation option menu.
    """

    fluent_name = "scene-animation"

    child_names = \
        ['set_custom_frames']

    set_custom_frames: set_custom_frames_cls = set_custom_frames_cls
    """
    set_custom_frames child of scene_animation.
    """
    command_names = \
        ['read_animation', 'write_animation', 'add_keyframe',
         'delete_keyframe', 'delete_all_keyframes', 'play']

    read_animation: read_animation_cls = read_animation_cls
    """
    read_animation command of scene_animation.
    """
    write_animation: write_animation_cls = write_animation_cls
    """
    write_animation command of scene_animation.
    """
    add_keyframe: add_keyframe_cls = add_keyframe_cls
    """
    add_keyframe command of scene_animation.
    """
    delete_keyframe: delete_keyframe_cls = delete_keyframe_cls
    """
    delete_keyframe command of scene_animation.
    """
    delete_all_keyframes: delete_all_keyframes_cls = delete_all_keyframes_cls
    """
    delete_all_keyframes command of scene_animation.
    """
    play: play_cls = play_cls
    """
    play command of scene_animation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled import enabled as enabled_cls
from .viscous_dissipation import viscous_dissipation as viscous_dissipation_cls
from .pressure_work import pressure_work as pressure_work_cls
from .kinetic_energy import kinetic_energy as kinetic_energy_cls
from .inlet_diffusion import inlet_diffusion as inlet_diffusion_cls
class energy(Group):
    """
    Enter the energy transport model settings.
    """

    fluent_name = "energy"

    child_names = \
        ['enabled', 'viscous_dissipation', 'pressure_work', 'kinetic_energy',
         'inlet_diffusion']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of energy.
    """
    viscous_dissipation: viscous_dissipation_cls = viscous_dissipation_cls
    """
    viscous_dissipation child of energy.
    """
    pressure_work: pressure_work_cls = pressure_work_cls
    """
    pressure_work child of energy.
    """
    kinetic_energy: kinetic_energy_cls = kinetic_energy_cls
    """
    kinetic_energy child of energy.
    """
    inlet_diffusion: inlet_diffusion_cls = inlet_diffusion_cls
    """
    inlet_diffusion child of energy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class new_framework_for_vof_specific_node_based_treatment(Boolean):
    """
    Enable/disable new framework for vof specific node based treatments.
    """

    fluent_name = "new-framework-for-vof-specific-node-based-treatment?"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class reorder:
    fluent_name = ...
    command_names = ...

    def band_width(self, ):
        """
        Print cell bandwidth.
        """

    def reorder_domain(self, ):
        """
        Reorder cells and faces by reverse Cuthill-McKee.
        """

    def reorder_zones(self, ):
        """
        Reorder zones by partition, type, and id.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .step_size import step_size as step_size_cls
from .tolerance_2 import tolerance as tolerance_cls
class accuracy_control(Group):
    """
    'accuracy_control' child.
    """

    fluent_name = "accuracy-control"

    child_names = \
        ['option', 'step_size', 'tolerance']

    option: option_cls = option_cls
    """
    option child of accuracy_control.
    """
    step_size: step_size_cls = step_size_cls
    """
    step_size child of accuracy_control.
    """
    tolerance: tolerance_cls = tolerance_cls
    """
    tolerance child of accuracy_control.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_9 import enable as enable_cls
from .disable_1 import disable as disable_cls
from .copy_2 import copy as copy_cls
from .delete_1 import delete as delete_cls
from .export_1 import export as export_cls
from .import__1 import import_ as import__cls
class execute_commands(Group):
    """
    'execute_commands' child.
    """

    fluent_name = "execute-commands"

    command_names = \
        ['enable', 'disable', 'copy', 'delete', 'export', 'import_']

    enable: enable_cls = enable_cls
    """
    enable command of execute_commands.
    """
    disable: disable_cls = disable_cls
    """
    disable command of execute_commands.
    """
    copy: copy_cls = copy_cls
    """
    copy command of execute_commands.
    """
    delete: delete_cls = delete_cls
    """
    delete command of execute_commands.
    """
    export: export_cls = export_cls
    """
    export command of execute_commands.
    """
    import_: import__cls = import__cls
    """
    import_ command of execute_commands.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class minimum_cell_quality(Real):
    """
    Set the minimum orthogonal quality bound for adapted cells.
    """

    fluent_name = "minimum-cell-quality"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class linearized_source_terms_limiter(Real):
    """
    Relative limit for DPM source linear coefficient with respect to fluid linear Ap coefficient.
    """

    fluent_name = "linearized-source-terms-limiter"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_defs import report_defs as report_defs_cls
class compute(Command):
    """
    'compute' command.
    
    Parameters
    ----------
        report_defs : typing.List[str]
            'report_defs' child.
    
    """

    fluent_name = "compute"

    argument_names = \
        ['report_defs']

    report_defs: report_defs_cls = report_defs_cls
    """
    report_defs argument of compute.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .source_update_every_iteration_enabled import source_update_every_iteration_enabled as source_update_every_iteration_enabled_cls
from .iteration_interval import iteration_interval as iteration_interval_cls
class interaction(Group):
    """
    'interaction' child.
    """

    fluent_name = "interaction"

    child_names = \
        ['option', 'source_update_every_iteration_enabled',
         'iteration_interval']

    option: option_cls = option_cls
    """
    option child of interaction.
    """
    source_update_every_iteration_enabled: source_update_every_iteration_enabled_cls = source_update_every_iteration_enabled_cls
    """
    source_update_every_iteration_enabled child of interaction.
    """
    iteration_interval: iteration_interval_cls = iteration_interval_cls
    """
    iteration_interval child of interaction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class warped_face_gradient_correction:
    fluent_name = ...
    child_names = ...
    turbulence_options = ...
    command_names = ...

    def enable(self, enable: bool, gradient_correction_mode: str):
        """
        Enable Warped-Face Gradient Correction.
        
        Parameters
        ----------
            enable : bool
                'enable' child.
            gradient_correction_mode : str
                'gradient_correction_mode' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .auto_scale import auto_scale as auto_scale_cls
from .scale_f import scale_f as scale_f_cls
class scale(Group):
    """
    'scale' child.
    """

    fluent_name = "scale"

    child_names = \
        ['auto_scale', 'scale_f']

    auto_scale: auto_scale_cls = auto_scale_cls
    """
    auto_scale child of scale.
    """
    scale_f: scale_f_cls = scale_f_cls
    """
    scale_f child of scale.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .forward_scattering_factor import forward_scattering_factor as forward_scattering_factor_cls
from .asymmetry_factor import asymmetry_factor as asymmetry_factor_cls
class delta_eddington(Group):
    """
    'delta_eddington' child.
    """

    fluent_name = "delta-eddington"

    child_names = \
        ['forward_scattering_factor', 'asymmetry_factor']

    forward_scattering_factor: forward_scattering_factor_cls = forward_scattering_factor_cls
    """
    forward_scattering_factor child of delta_eddington.
    """
    asymmetry_factor: asymmetry_factor_cls = asymmetry_factor_cls
    """
    asymmetry_factor child of delta_eddington.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class length_to_head_ratio(Real):
    """
    'length_to_head_ratio' child.
    """

    fluent_name = "length-to-head-ratio"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_name import report_name as report_name_cls
class reset_report_to_defaults(Command):
    """
    Reset all report settings to default for the provided simulation report.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
    
    """

    fluent_name = "reset-report-to-defaults"

    argument_names = \
        ['report_name']

    report_name: report_name_cls = report_name_cls
    """
    report_name argument of reset_report_to_defaults.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class specify_species_in_mole_fractions(Boolean, _HasAllowedValuesMixin):
    """
    Specify Species in Mole Fractions?.
    """

    fluent_name = "specify-species-in-mole-fractions?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .density_2 import density as density_cls
from .viscosity_1 import viscosity as viscosity_cls
from .specific_heat_2 import specific_heat as specific_heat_cls
from .thermal_conductivity_2 import thermal_conductivity as thermal_conductivity_cls
from .premix_laminar_speed import premix_laminar_speed as premix_laminar_speed_cls
from .premix_laminar_thickness import premix_laminar_thickness as premix_laminar_thickness_cls
from .premix_unburnt_temp_1 import premix_unburnt_temp as premix_unburnt_temp_cls
from .premix_unburnt_cp import premix_unburnt_cp as premix_unburnt_cp_cls
from .premix_unburnt_density_1 import premix_unburnt_density as premix_unburnt_density_cls
from .premix_heat_trans_coeff_1 import premix_heat_trans_coeff as premix_heat_trans_coeff_cls
from .premix_critical_strain import premix_critical_strain as premix_critical_strain_cls
from .therm_exp_coeff import therm_exp_coeff as therm_exp_coeff_cls
from .absorption_coefficient_1 import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .refractive_index import refractive_index as refractive_index_cls
from .mass_diffusivity_1 import mass_diffusivity as mass_diffusivity_cls
from .species import species as species_cls
from .reactions import reactions as reactions_cls
from .reaction_mechs import reaction_mechs as reaction_mechs_cls
from .uds_diffusivity import uds_diffusivity as uds_diffusivity_cls
from .thermal_diffusivity import thermal_diffusivity as thermal_diffusivity_cls
from .tmelt import tmelt as tmelt_cls
from .melting_heat import melting_heat as melting_heat_cls
from .eutectic_temp import eutectic_temp as eutectic_temp_cls
from .speed_of_sound import speed_of_sound as speed_of_sound_cls
from .critical_temperature import critical_temperature as critical_temperature_cls
from .critical_pressure import critical_pressure as critical_pressure_cls
from .critical_volume import critical_volume as critical_volume_cls
from .acentric_factor import acentric_factor as acentric_factor_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .collision_cross_section import collision_cross_section as collision_cross_section_cls
from .mixture_species import mixture_species as mixture_species_cls
class mixture_child(Group):
    """
    'child_object_type' of mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'viscosity', 'specific_heat', 'thermal_conductivity',
         'premix_laminar_speed', 'premix_laminar_thickness',
         'premix_unburnt_temp', 'premix_unburnt_cp', 'premix_unburnt_density',
         'premix_heat_trans_coeff', 'premix_critical_strain',
         'therm_exp_coeff', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'refractive_index', 'mass_diffusivity', 'species', 'reactions',
         'reaction_mechs', 'uds_diffusivity', 'thermal_diffusivity', 'tmelt',
         'melting_heat', 'eutectic_temp', 'speed_of_sound',
         'critical_temperature', 'critical_pressure', 'critical_volume',
         'acentric_factor', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'collision_cross_section', 'mixture_species']

    density: density_cls = density_cls
    """
    density child of mixture_child.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of mixture_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of mixture_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of mixture_child.
    """
    premix_laminar_speed: premix_laminar_speed_cls = premix_laminar_speed_cls
    """
    premix_laminar_speed child of mixture_child.
    """
    premix_laminar_thickness: premix_laminar_thickness_cls = premix_laminar_thickness_cls
    """
    premix_laminar_thickness child of mixture_child.
    """
    premix_unburnt_temp: premix_unburnt_temp_cls = premix_unburnt_temp_cls
    """
    premix_unburnt_temp child of mixture_child.
    """
    premix_unburnt_cp: premix_unburnt_cp_cls = premix_unburnt_cp_cls
    """
    premix_unburnt_cp child of mixture_child.
    """
    premix_unburnt_density: premix_unburnt_density_cls = premix_unburnt_density_cls
    """
    premix_unburnt_density child of mixture_child.
    """
    premix_heat_trans_coeff: premix_heat_trans_coeff_cls = premix_heat_trans_coeff_cls
    """
    premix_heat_trans_coeff child of mixture_child.
    """
    premix_critical_strain: premix_critical_strain_cls = premix_critical_strain_cls
    """
    premix_critical_strain child of mixture_child.
    """
    therm_exp_coeff: therm_exp_coeff_cls = therm_exp_coeff_cls
    """
    therm_exp_coeff child of mixture_child.
    """
    absorption_coefficient: absorption_coefficient_cls = absorption_coefficient_cls
    """
    absorption_coefficient child of mixture_child.
    """
    scattering_coefficient: scattering_coefficient_cls = scattering_coefficient_cls
    """
    scattering_coefficient child of mixture_child.
    """
    scattering_phase_function: scattering_phase_function_cls = scattering_phase_function_cls
    """
    scattering_phase_function child of mixture_child.
    """
    refractive_index: refractive_index_cls = refractive_index_cls
    """
    refractive_index child of mixture_child.
    """
    mass_diffusivity: mass_diffusivity_cls = mass_diffusivity_cls
    """
    mass_diffusivity child of mixture_child.
    """
    species: species_cls = species_cls
    """
    species child of mixture_child.
    """
    reactions: reactions_cls = reactions_cls
    """
    reactions child of mixture_child.
    """
    reaction_mechs: reaction_mechs_cls = reaction_mechs_cls
    """
    reaction_mechs child of mixture_child.
    """
    uds_diffusivity: uds_diffusivity_cls = uds_diffusivity_cls
    """
    uds_diffusivity child of mixture_child.
    """
    thermal_diffusivity: thermal_diffusivity_cls = thermal_diffusivity_cls
    """
    thermal_diffusivity child of mixture_child.
    """
    tmelt: tmelt_cls = tmelt_cls
    """
    tmelt child of mixture_child.
    """
    melting_heat: melting_heat_cls = melting_heat_cls
    """
    melting_heat child of mixture_child.
    """
    eutectic_temp: eutectic_temp_cls = eutectic_temp_cls
    """
    eutectic_temp child of mixture_child.
    """
    speed_of_sound: speed_of_sound_cls = speed_of_sound_cls
    """
    speed_of_sound child of mixture_child.
    """
    critical_temperature: critical_temperature_cls = critical_temperature_cls
    """
    critical_temperature child of mixture_child.
    """
    critical_pressure: critical_pressure_cls = critical_pressure_cls
    """
    critical_pressure child of mixture_child.
    """
    critical_volume: critical_volume_cls = critical_volume_cls
    """
    critical_volume child of mixture_child.
    """
    acentric_factor: acentric_factor_cls = acentric_factor_cls
    """
    acentric_factor child of mixture_child.
    """
    electric_conductivity: electric_conductivity_cls = electric_conductivity_cls
    """
    electric_conductivity child of mixture_child.
    """
    dual_electric_conductivity: dual_electric_conductivity_cls = dual_electric_conductivity_cls
    """
    dual_electric_conductivity child of mixture_child.
    """
    lithium_diffusivity: lithium_diffusivity_cls = lithium_diffusivity_cls
    """
    lithium_diffusivity child of mixture_child.
    """
    collision_cross_section: collision_cross_section_cls = collision_cross_section_cls
    """
    collision_cross_section child of mixture_child.
    """
    mixture_species: mixture_species_cls = mixture_species_cls
    """
    mixture_species child of mixture_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class import_:
    fluent_name = ...
    child_names = ...
    create_zones_from_ccl = ...
    command_names = ...

    def read(self, file_type: str, file_name: str):
        """
        'read' command.
        
        Parameters
        ----------
            file_type : str
                'file_type' child.
            file_name : str
                'file_name' child.
        
        """

    def chemkin_report_each_line(self, report_each_line: bool):
        """
        'chemkin_report_each_line' command.
        
        Parameters
        ----------
            report_each_line : bool
                Enable/disable reporting after reading each line.
        
        """

    def import_fmu(self, file_name: str):
        """
        Import a FMU file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .automatic import automatic as automatic_cls
from .manual import manual as manual_cls
class coloring(Group):
    """
    'coloring' child.
    """

    fluent_name = "coloring"

    child_names = \
        ['option', 'automatic', 'manual']

    option: option_cls = option_cls
    """
    option child of coloring.
    """
    automatic: automatic_cls = automatic_cls
    """
    automatic child of coloring.
    """
    manual: manual_cls = manual_cls
    """
    manual child of coloring.
    """



"""Provides a module for launching Fluent in container mode."""

import logging
import os
from typing import Any, Dict, Optional, Union

from ansys.fluent.core.fluent_connection import FluentConnection
from ansys.fluent.core.launcher.fluent_container import (
    configure_container_dict,
    start_fluent_container,
)
from ansys.fluent.core.launcher.launcher_utils import (
    FluentMode,
    _build_fluent_launch_args_string,
    _get_argvals,
    _process_invalid_args,
    _process_kwargs,
)
import ansys.fluent.core.launcher.watchdog as watchdog
from ansys.fluent.core.utils.file_transfer_service import RemoteFileHandler

_THIS_DIR = os.path.dirname(__file__)
_OPTIONS_FILE = os.path.join(_THIS_DIR, "fluent_launcher_options.json")
logger = logging.getLogger("pyfluent.launcher")


class DockerLauncher:
    """Instantiates Fluent session in container mode."""

    def __init__(
        self,
        argvals: Optional[Any] = None,
        product_version: Optional[str] = None,
        version: Optional[str] = None,
        precision: Optional[str] = None,
        processor_count: Optional[int] = None,
        journal_file_names: Union[None, str, list[str]] = None,
        start_timeout: int = 60,
        additional_arguments: Optional[str] = "",
        env: Optional[Dict[str, Any]] = None,
        start_container: Optional[bool] = None,
        container_dict: Optional[dict] = None,
        dry_run: bool = False,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
        show_gui: Optional[bool] = None,
        case_file_name: Optional[str] = None,
        case_data_file_name: Optional[str] = None,
        lightweight_mode: Optional[bool] = None,
        mode: Optional[Union[FluentMode, str, None]] = None,
        py: Optional[bool] = None,
        gpu: Optional[bool] = None,
        cwd: Optional[str] = None,
        topy: Optional[Union[str, list]] = None,
        start_watchdog: Optional[bool] = None,
        scheduler_options: Optional[dict] = None,
        **kwargs,
    ):
        """Launch Fluent session in container mode.

        Parameters
        ----------
        product_version : str, optional
            Select an installed version of ANSYS. The string must be in a format like
            ``"23.2.0"`` (for 2023 R2) matching the documented version format in the
            FluentVersion class. The default is ``None``, in which case the newest installed
            version is used.
        version : str, optional
            Geometric dimensionality of the Fluent simulation. The default is ``None``,
            in which case ``"3d"`` is used. Options are ``"3d"`` and ``"2d"``.
        precision : str, optional
            Floating point precision. The default is ``None``, in which case ``"double"``
            is used. Options are ``"double"`` and ``"single"``.
        processor_count : int, optional
            Number of processors. The default is ``None``, in which case ``1``
            processor is used.  In job scheduler environments the total number of
            allocated cores is clamped to value of ``processor_count``.
        journal_file_names : str or list of str, optional
            The string path to a Fluent journal file, or a list of such paths. Fluent will execute the
            journal(s). The default is ``None``.
        start_timeout : int, optional
            Maximum allowable time in seconds for connecting to the Fluent
            server. The default is ``60``.
        additional_arguments : str, optional
            Additional arguments to send to Fluent as a string in the same
            format they are normally passed to Fluent on the command line.
        env : dict[str, str], optional
            Mapping to modify environment variables in Fluent. The default
            is ``None``.
        start_container : bool, optional
            Specifies whether to launch a Fluent Docker container image. For more details about containers, see
            :mod:`~ansys.fluent.core.launcher.fluent_container`.
        container_dict : dict, optional
            Dictionary for Fluent Docker container configuration. If specified,
            setting ``start_container = True`` as well is redundant.
            Will launch Fluent inside a Docker container using the configuration changes specified.
            See also :mod:`~ansys.fluent.core.launcher.fluent_container`.
        dry_run : bool, optional
            Defaults to False. If True, will not launch Fluent, and will instead print configuration information
            that would be used as if Fluent was being launched. If dry running a container start,
            ``launch_fluent()`` will return the configured ``container_dict``.
        cleanup_on_exit : bool, optional
            Whether to shut down the connected Fluent session when PyFluent is
            exited, or the ``exit()`` method is called on the session instance,
            or if the session instance becomes unreferenced. The default is ``True``.
        start_transcript : bool, optional
            Whether to start streaming the Fluent transcript in the client. The
            default is ``True``. You can stop and start the streaming of the
            Fluent transcript subsequently via the method calls, ``transcript.start()``
            and ``transcript.stop()`` on the session object.
        show_gui : bool, optional
            Whether to display the Fluent GUI. The default is ``None``, which does not
            cause the GUI to be shown. If a value of ``False`` is
            not explicitly provided, the GUI will also be shown if
            the environment variable ``PYFLUENT_SHOW_SERVER_GUI`` is set to 1.
        case_file_name : str, optional
            If provided, the case file at ``case_file_name`` is read into the Fluent session.
        case_data_file_name : str, optional
            If provided, the case and data files at ``case_data_file_name`` are read into the Fluent session.
        lightweight_mode : bool, optional
            Whether to run in lightweight mode. In lightweight mode, the lightweight settings are read into the
            current Fluent solver session. The mesh is read into a background Fluent solver session which will
            replace the current Fluent solver session once the mesh read is complete and the lightweight settings
            made by the user in the current Fluent solver session have been applied in the background Fluent
            solver session. This is all orchestrated by PyFluent and requires no special usage.
            This parameter is used only when ``case_file_name`` is provided. The default is ``False``.
        mode : str, optional
            Launch mode of Fluent to point to a specific session type.
            The default value is ``None``. Options are ``"meshing"``,
            ``"pure-meshing"`` and ``"solver"``.
        py : bool, optional
            If True, Fluent will run in Python mode. Default is None.
        gpu : bool, optional
            If True, Fluent will start with GPU Solver.
        cwd : str, Optional
            Working directory for the Fluent client.
        topy : bool or str, optional
            A boolean flag to write the equivalent Python journal(s) from the journal(s) passed.
            Can optionally take the file name of the new python journal file.
        start_watchdog : bool, optional
            When ``cleanup_on_exit`` is True, ``start_watchdog`` defaults to True,
            which means an independent watchdog process is run to ensure
            that any local GUI-less Fluent sessions started by PyFluent are properly closed (or killed if frozen)
            when the current Python process ends.

        Returns
        -------
        :obj:`~typing.Union` [:class:`Meshing<ansys.fluent.core.session_meshing.Meshing>`, \
        :class:`~ansys.fluent.core.session_pure_meshing.PureMeshing`, \
        :class:`~ansys.fluent.core.session_solver.Solver`, \
        :class:`~ansys.fluent.core.session_solver_icing.SolverIcing`, dict]
            Session object or configuration dictionary if ``dry_run = True``.

        Raises
        ------
        UnexpectedKeywordArgument
            If an unexpected keyword argument is provided.
        DockerContainerLaunchNotSupported
            If a Fluent Docker container launch is not supported.

        Notes
        -----
        Job scheduler environments such as SLURM, LSF, PBS, etc. allocates resources / compute nodes.
        The allocated machines and core counts are queried from the scheduler environment and
        passed to Fluent.
        """
        _process_kwargs(kwargs)
        del kwargs
        del start_container
        argvals = locals().copy()
        _process_invalid_args(dry_run, "container", argvals)
        args = _get_argvals(argvals, mode)
        argvals.update(args)
        if argvals["start_timeout"] is None:
            argvals["start_timeout"] = 60
        for arg_name, arg_values in argvals.items():
            setattr(self, arg_name, arg_values)
        self.argvals = argvals

    def __call__(self):
        args = _build_fluent_launch_args_string(**self.argvals).split()
        if self.meshing_mode:
            args.append(" -meshing")
        if self.container_dict is None:
            setattr(self, "container_dict", {})
        if self.product_version:
            self.container_dict["image_tag"] = f"v{self.product_version}"
        if self.dry_run:
            config_dict, *_ = configure_container_dict(args, **self.container_dict)
            from pprint import pprint

            print("\nDocker container run configuration:\n")
            print("config_dict = ")
            if os.getenv("PYFLUENT_HIDE_LOG_SECRETS") != "1":
                pprint(config_dict)
            else:
                config_dict_h = config_dict.copy()
                config_dict_h.pop("environment")
                pprint(config_dict_h)
                del config_dict_h
            return config_dict

        port, password = start_fluent_container(args, self.container_dict)

        session = self.new_session(
            fluent_connection=FluentConnection(
                port=port,
                password=password,
                cleanup_on_exit=self.cleanup_on_exit,
                start_transcript=self.start_transcript,
                launcher_args=self.argvals,
                inside_container=True,
            ),
            remote_file_handler=RemoteFileHandler(),
        )

        if self.start_watchdog is None and self.cleanup_on_exit:
            setattr(self, "start_watchdog", True)
        if self.start_watchdog:
            logger.debug("Launching Watchdog for Fluent container...")
            watchdog.launch(os.getpid(), port, password)

        return session



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .convective_heat_transfer import convective_heat_transfer as convective_heat_transfer_cls
from .include_convective_heat_transfer import include_convective_heat_transfer as include_convective_heat_transfer_cls
from .film_movement import film_movement as film_movement_cls
from .film_adds_to_dpm_concentration import film_adds_to_dpm_concentration as film_adds_to_dpm_concentration_cls
from .temperature_limiter import temperature_limiter as temperature_limiter_cls
class wall_film(Group):
    """
    'wall_film' child.
    """

    fluent_name = "wall-film"

    child_names = \
        ['convective_heat_transfer', 'include_convective_heat_transfer',
         'film_movement', 'film_adds_to_dpm_concentration',
         'temperature_limiter']

    convective_heat_transfer: convective_heat_transfer_cls = convective_heat_transfer_cls
    """
    convective_heat_transfer child of wall_film.
    """
    include_convective_heat_transfer: include_convective_heat_transfer_cls = include_convective_heat_transfer_cls
    """
    include_convective_heat_transfer child of wall_film.
    """
    film_movement: film_movement_cls = film_movement_cls
    """
    film_movement child of wall_film.
    """
    film_adds_to_dpm_concentration: film_adds_to_dpm_concentration_cls = film_adds_to_dpm_concentration_cls
    """
    film_adds_to_dpm_concentration child of wall_film.
    """
    temperature_limiter: temperature_limiter_cls = temperature_limiter_cls
    """
    temperature_limiter child of wall_film.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_12 import enabled as enabled_cls
from .clustering_type import clustering_type as clustering_type_cls
from .nx import nx as nx_cls
from .ny import ny as ny_cls
from .nz import nz as nz_cls
from .cluster_number import cluster_number as cluster_number_cls
from .target_variable import target_variable as target_variable_cls
from .udf_name import udf_name as udf_name_cls
class cell_clustering(Group):
    """
    'cell_clustering' child.
    """

    fluent_name = "cell-clustering"

    child_names = \
        ['enabled', 'clustering_type', 'nx', 'ny', 'nz', 'cluster_number',
         'target_variable', 'udf_name']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of cell_clustering.
    """
    clustering_type: clustering_type_cls = clustering_type_cls
    """
    clustering_type child of cell_clustering.
    """
    nx: nx_cls = nx_cls
    """
    nx child of cell_clustering.
    """
    ny: ny_cls = ny_cls
    """
    ny child of cell_clustering.
    """
    nz: nz_cls = nz_cls
    """
    nz child of cell_clustering.
    """
    cluster_number: cluster_number_cls = cluster_number_cls
    """
    cluster_number child of cell_clustering.
    """
    target_variable: target_variable_cls = target_variable_cls
    """
    target_variable child of cell_clustering.
    """
    udf_name: udf_name_cls = udf_name_cls
    """
    udf_name child of cell_clustering.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .shape_factor import shape_factor as shape_factor_cls
from .cunningham_factor import cunningham_factor as cunningham_factor_cls
class particle_drag(Group):
    """
    'particle_drag' child.
    """

    fluent_name = "particle-drag"

    child_names = \
        ['option', 'shape_factor', 'cunningham_factor']

    option: option_cls = option_cls
    """
    option child of particle_drag.
    """
    shape_factor: shape_factor_cls = shape_factor_cls
    """
    shape_factor child of particle_drag.
    """
    cunningham_factor: cunningham_factor_cls = cunningham_factor_cls
    """
    cunningham_factor child of particle_drag.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .dbns_cases import dbns_cases as dbns_cases_cls
from .pbns_cases import pbns_cases as pbns_cases_cls
class flux_type(Group):
    """
    Enter the flux type.
    """

    fluent_name = "flux-type"

    child_names = \
        ['dbns_cases', 'pbns_cases']

    dbns_cases: dbns_cases_cls = dbns_cases_cls
    """
    dbns_cases child of flux_type.
    """
    pbns_cases: pbns_cases_cls = pbns_cases_cls
    """
    pbns_cases child of flux_type.
    """
